# (C) Copyright 2005- ECMWF.

# TEMPLATE 3.1000, Cross-section grid, with points equally spaced on the horizontal

include "grib2/template.3.shape_of_the_earth.def";


#  Number of horizontal points
unsigned[4] numberOfHorizontalPoints  : dump ;

#  Basic angle of the initial production domain
unsigned[4] basicAngleOfTheInitialProductionDomain = 0;

#  Subdivisions of basic angle used to define extreme longitudes and latitudes
unsigned[4] subdivisionsOfBasicAngle = missing() : can_be_missing;;

#  La1 - latitude of first grid point
signed[4] latitudeOfFirstGridPoint : edition_specific ;

alias La1 =  latitudeOfFirstGridPoint;
#  Lo1 - longitude of first grid point
unsigned[4] longitudeOfFirstGridPoint : edition_specific;

alias Lo1 =  longitudeOfFirstGridPoint;

include "grib2/template.3.scanning_mode.def";

#  La2 - latitude of last grid point
signed[4] latitudeOfLastGridPoint : edition_specific;

alias La2  = latitudeOfLastGridPoint;
#  Lo2 - longitude of last grid point
unsigned[4] longitudeOfLastGridPoint: edition_specific ;

alias Lo2 =  longitudeOfLastGridPoint;
#  Type of horizontal line
codetable[1] typeOfHorizontalLine ('3.20.table',masterDir,localDir) : dump ;

#  Number of vertical points
unsigned[2] numberOfVerticalPoints  : dump ;

#  Physical meaning of vertical coordinate
codetable[1] meaningOfVerticalCoordinate ('3.15.table',masterDir,localDir) : dump ;

#  Vertical dimension coordinate values definition
codetable[1] verticalCoordinate ('3.21.table',masterDir,localDir) : dump ;

#  NC - Number of coefficients or values used to specify vertical coordinates
unsigned[2] NC  : dump ;

# Octets 67-(66+NC*4) : Coefficients to define vertical dimension coordinate values in functional form, or the explicit coordinate values
# (IEEE 32-bit floating-point values)
# ????          coefficients_to_define_vertical_dimension_coordinate_values_in_functional_form_or_the_explicit_coordinate_values


