# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.84, Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol with source or sink
include "grib2/template.4.parameter_aerosol_source.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.eps.def"
include "grib2/template.4.statistical.def"
