# (C) Copyright 2005- ECMWF.

# TEMPLATE 3.1100, Hovmoller diagram grid with points equally spaced on the horizontal
include "grib2/template.3.shape_of_the_earth.def";

#  Number of horizontal points
unsigned[5] numberOfHorizontalPoints : dump ;

#  Basic angle of the initial production domain
unsigned[4] basicAngleOfTheInitialProductionDomain = 0 : dump ;

#  Subdivisions of basic angle used to define extreme longitudes and latitudes
unsigned[4] subdivisionsOfBasicAngle = missing() : can_be_missing,dump;

#  La1 - latitude of first grid point
signed[4] latitudeOfFirstGridPoint : edition_specific,dump;

alias La1  =latitudeOfFirstGridPoint;
#  Lo1 - longitude of first grid point
unsigned[4] longitudeOfFirstGridPoint : edition_specific,dump;

alias Lo1  =longitudeOfFirstGridPoint;

include "grib2/template.3.scanning_mode.def";

#  La2 - latitude of last grid point
signed[4] latitudeOfLastGridPoint : edition_specific,dump;

alias La2  = latitudeOfLastGridPoint;
#  Lo2 - longitude of last grid point
unsigned[4] longitudeOfLastGridPoint : edition_specific,dump ;

alias Lo2  = longitudeOfLastGridPoint;
#  Type of horizontal line
codetable[1] typeOfHorizontalLine ('3.20.table',masterDir,localDir) : dump;

#  NT - Number of time steps
unsigned[4] numberOfTimeSteps : dump;

alias NT =  numberOfTimeSteps;
#  Unit of offset from reference time
codetable[1] unitOfOffsetFromReferenceTime ('4.4.table',masterDir,localDir) : dump;

#  Offset from reference of first time
# (negative value when first bit set)
unsigned[4] offsetFromReferenceOfFirstTime ;

#  Type of time increment
codetable[1] typeOfTimeIncrement ('4.11.table',masterDir,localDir) : dump;

#  Unit of time increment
codetable[1] unitOfTimeIncrement ('4.4.table',masterDir,localDir) : dump;

#  Time increment
# (negative value when first bit set)
unsigned[4] timeIncrement : dump ;

#  Year
unsigned[2] year  : dump;

#  Month
unsigned[1] month  : dump;

#  Day
unsigned[1] day  : dump;

#  Hour
unsigned[1] hour  : dump;

#  Minute
unsigned[1] minute  : dump;

#  Second
unsigned[1] second  : dump;

