# (C) Copyright 2005- ECMWF.

# Forecast probability number
unsigned[1] forecastProbabilityNumber  : dump;

# Total number of forecast probabilities
unsigned[1] totalNumberOfForecastProbabilities  : dump;

# Probability type
codetable[1] probabilityType ('4.9.table',masterDir,localDir) : dump;
meta probabilityTypeName codetable_title(probabilityType): read_only;

# Scale factor of lower limit
signed[1] scaleFactorOfLowerLimit : can_be_missing,dump ;

# Scaled value of lower limit
signed[4] scaledValueOfLowerLimit : can_be_missing,dump ;

meta lowerLimit from_scale_factor_scaled_value(
     scaleFactorOfLowerLimit, scaledValueOfLowerLimit): can_be_missing;


# Scale factor of upper limit
signed[1] scaleFactorOfUpperLimit : can_be_missing,dump;

# Scaled value of upper limit
signed[4] scaledValueOfUpperLimit : can_be_missing,dump;

meta upperLimit from_scale_factor_scaled_value(
     scaleFactorOfUpperLimit, scaledValueOfUpperLimit): can_be_missing;
