# Automatically generated by ./tigge_def.pl, do not edit

# 10_meter_u_velocity
'165' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 2;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 10;
	 typeOfFirstFixedSurface = 103;
}

# 10_meter_v_velocity
'166' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 3;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 10;
	 typeOfFirstFixedSurface = 103;
}

# 10_metre_wind_gust_of_at_least_15_m/s
'131070' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 22;
	 productDefinitionTemplateNumber = 9;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 10;
	 scaledValueOfLowerLimit = 15;
	 typeOfFirstFixedSurface = 103;
	 typeOfStatisticalProcessing = 2;
}

# 10_metre_wind_gust_of_at_least_25_m/s
'131071' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 22;
	 productDefinitionTemplateNumber = 9;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 10;
	 scaledValueOfLowerLimit = 25;
	 typeOfFirstFixedSurface = 103;
	 typeOfStatisticalProcessing = 2;
}

# convective_available_potential_energy
'59' = {
	 discipline = 0;
	 parameterCategory = 7;
	 parameterNumber = 6;
	 typeOfFirstFixedSurface = 1;
	 typeOfSecondFixedSurface = 8;
}

# convective_inhibition
'228001' = {
	 discipline = 0;
	 parameterCategory = 7;
	 parameterNumber = 7;
	 typeOfFirstFixedSurface = 1;
	 typeOfSecondFixedSurface = 8;
}

# field_capacity
'228170' = {
	 discipline = 2;
	 parameterCategory = 3;
	 parameterNumber = 12;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaleFactorOfSecondFixedSurface = 1;
	 scaledValueOfFirstFixedSurface = 0;
	 scaledValueOfSecondFixedSurface = 2;
	 typeOfFirstFixedSurface = 106;
	 typeOfSecondFixedSurface = 106;
}

# geopotential_height
'156' = {
	 discipline = 0;
	 parameterCategory = 3;
	 parameterNumber = 5;
	 typeOfFirstFixedSurface = 100;
}

# land_sea_mask
'172' = {
	 discipline = 2;
	 parameterCategory = 0;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 1;
}

# maximum_wind_gust
'49' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 22;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 10;
	 typeOfFirstFixedSurface = 103;
	 typeOfStatisticalProcessing = 2;
}

# mean_sea_level_pressure
'151' = {
	 discipline = 0;
	 parameterCategory = 3;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 101;
}

# orography
'228002' = {
	 discipline = 0;
	 parameterCategory = 3;
	 parameterNumber = 5;
	 typeOfFirstFixedSurface = 1;
}

# potential_temperature
'3' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 2;
	 scaleFactorOfFirstFixedSurface = 6;
	 scaledValueOfFirstFixedSurface = 2;
	 typeOfFirstFixedSurface = 109;
}

# potential_vorticity
'60' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 14;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaledValueOfFirstFixedSurface = 320;
	 typeOfFirstFixedSurface = 107;
}

# sea_surface_temperature_anomaly
'171034' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 9;
	 typeOfFirstFixedSurface = 1;
}

# skin_temperature
'235' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 17;
	 typeOfFirstFixedSurface = 1;
}

# snow_depth_water_equivalent
'228141' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 60;
	 typeOfFirstFixedSurface = 1;
}

# snow_fall_water_equivalent
'228144' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 53;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# soil_moisture
'228039' = {
	 discipline = 2;
	 parameterCategory = 0;
	 parameterNumber = 22;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaleFactorOfSecondFixedSurface = 1;
	 scaledValueOfFirstFixedSurface = 0;
	 scaledValueOfSecondFixedSurface = 2;
	 typeOfFirstFixedSurface = 106;
	 typeOfSecondFixedSurface = 106;
}

# soil_temperature
'228139' = {
	 discipline = 2;
	 parameterCategory = 0;
	 parameterNumber = 2;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaleFactorOfSecondFixedSurface = 1;
	 scaledValueOfFirstFixedSurface = 0;
	 scaledValueOfSecondFixedSurface = 2;
	 typeOfFirstFixedSurface = 106;
	 typeOfSecondFixedSurface = 106;
}

# specific_humidity
'133' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 100;
}

# sunshine_duration
'189' = {
	 discipline = 0;
	 parameterCategory = 6;
	 parameterNumber = 24;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# surface_air_dew_point_temperature
'168' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 6;
	 typeOfFirstFixedSurface = 103;
}

# surface_air_maximum_temperature
'121' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 103;
	 typeOfStatisticalProcessing = 2;
}

# surface_air_minimum_temperature
'122' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 103;
	 typeOfStatisticalProcessing = 3;
}

# surface_air_temperature
'167' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 103;
}

# surface_pressure
'134' = {
	 discipline = 0;
	 parameterCategory = 3;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 1;
}

# temperature
'130' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 0;
	 typeOfFirstFixedSurface = 100;
}

# time_integrated_outgoing_long_wave_radiation
'179' = {
	 discipline = 0;
	 parameterCategory = 5;
	 parameterNumber = 5;
	 typeOfFirstFixedSurface = 8;
	 typeOfStatisticalProcessing = 1;
}

# time_integrated_surface_latent_heat_flux
'147' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 10;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# time_integrated_surface_net_solar_radiation
'176' = {
	 discipline = 0;
	 parameterCategory = 4;
	 parameterNumber = 9;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# time_integrated_surface_net_thermal_radiation
'177' = {
	 discipline = 0;
	 parameterCategory = 5;
	 parameterNumber = 5;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# time_integrated_surface_sensible_heat_flux
'146' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 11;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# total_cloud_cover
'228164' = {
	 discipline = 0;
	 parameterCategory = 6;
	 parameterNumber = 1;
	 typeOfFirstFixedSurface = 1;
	 typeOfSecondFixedSurface = 8;
}

# total_column_water
'136' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 51;
	 typeOfFirstFixedSurface = 1;
	 typeOfSecondFixedSurface = 8;
}

# total_precipitation
'228228' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 52;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# total_precipitation_of_at_least_10_mm
'131062' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 52;
	 productDefinitionTemplateNumber = 9;
	 scaledValueOfLowerLimit = 10;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# total_precipitation_of_at_least_20_mm
'131063' = {
	 discipline = 0;
	 parameterCategory = 1;
	 parameterNumber = 52;
	 productDefinitionTemplateNumber = 9;
	 scaledValueOfLowerLimit = 20;
	 typeOfFirstFixedSurface = 1;
	 typeOfStatisticalProcessing = 1;
}

# u_velocity
'131' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 2;
}

# unknown
'default' = {
	 discipline = 0;
	 parameterCategory = 0;
	 parameterNumber = 0;
}

# v_velocity
'132' = {
	 discipline = 0;
	 parameterCategory = 2;
	 parameterNumber = 3;
}

# wilting_point
'228171' = {
	 discipline = 2;
	 parameterCategory = 0;
	 parameterNumber = 26;
	 scaleFactorOfFirstFixedSurface = 0;
	 scaleFactorOfSecondFixedSurface = 1;
	 scaledValueOfFirstFixedSurface = 0;
	 scaledValueOfSecondFixedSurface = 2;
	 typeOfFirstFixedSurface = 106;
	 typeOfSecondFixedSurface = 106;
}
