#Provided by Inger-Lise Frogner (Norwegian Meteorological Institute)
#Total precipitation
'Total precipitation' = {
     table2Version = 1 ;
     indicatorOfParameter = 61 ;
    }
#Convective available potential energy
'Convective available potential energy' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 225 ;
}
#10 metre wind gust
'10 metre wind gust' = {
     table2Version = 1 ;
     indicatorOfParameter = 228 ;
    }
