#Surface net solar radiation, clear sky
'surface_net_downward_shortwave_flux_assuming_clear_sky' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 210 ;
}
#Surface net thermal radiation, clear sky
'surface_net_downward_longwave_flux_assuming_clear_sky' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 211 ;
}
#Eastward sea water velocity
'eastward_sea_water_velocity' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 131 ;
}
#Northward sea water velocity
'northward_sea_water_velocity' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 132 ;
}
#Sea-ice thickness
'sea_ice_thickness' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 98 ;
}
#Sea surface height
'sea_surface_height_above_geoid' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 145 ;
}
#Depth of 20C isotherm
'depth_of_isosurface_of_sea_water_potential_temperature' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 163 ;
}
#Top net solar radiation
'toa_net_upward_shortwave_flux' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 178 ;
}
#Temperature of snow layer
'temperature_in_surface_snow' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 238 ;
}
