# (C) Copyright 2005- ECMWF.

#  Type of ensemble forecast
codetable[1] typeOfEnsembleForecast ('4.6.table',masterDir,localDir) = 255 : dump;

#  Perturbation number
unsigned[1] perturbationNumber  : dump;
alias number=perturbationNumber;

#  Number of forecasts in ensemble
unsigned[1] numberOfForecastsInEnsemble  : dump;
alias totalNumber=numberOfForecastsInEnsemble;

#  Rules for TIGGE, S2S, UERRA and CRRA
if (productionStatusOfProcessedData == 4 ||
    productionStatusOfProcessedData == 5 ||
    productionStatusOfProcessedData == 6 ||
    productionStatusOfProcessedData == 7 ||
    productionStatusOfProcessedData == 8 ||
    productionStatusOfProcessedData == 9 ||
    productionStatusOfProcessedData == 10||
    productionStatusOfProcessedData == 11)
{
    alias mars.number=perturbationNumber;
}
