# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.53, Partitioned parameters at a horizontal level or in a horizontal layer at a point in time

include "grib2/template.4.parameter_partition.def"
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def";
constant cat="cat";
alias mars.levtype=cat;
alias mars.levelist=partitionNumber;
