# Automatically generated by ./create_def.pl, do not edit
#Pressure (S) (not reduced)
'Pa' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure
'Pa' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	}
#Pressure Reduced to MSL
'Pa' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#Pressure Tendency (S)
'Pa s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (S)
'm**2 s**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geopotential (full lev)
'm**2 s**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Geopotential
'm**2 s**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}
#Geometric Height of the earths surface above sea level
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Geometric Height of the layer limits above sea level(NN)
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Total Column Integrated Ozone
'Dobson' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature (G)
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#2m Temperature (AV)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Climat. temperature, 2m Temperature
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Temperature
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}
#Max 2m Temperature (i)
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#Min 2m Temperature (i)
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#2m Dew Point Temperature
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#2m Dew Point Temperature (AV)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 3 ;
	}
#Radar spectra (1)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Wave spectra (1)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra (2)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra (3)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 30 ;
	}
#Wind Direction (DD_10M)
'degrees' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind Direction (DD)
'degrees' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Wind speed (SP_10M)
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#Wind speed (SP)
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#U component of wind
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#U component of wind
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#V component of wind
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Pa s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical Velocity (Geometric) (w)
'm s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 40 ;
	}
#Specific Humidity (S)
'kg kg**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Specific Humidity (2m)
'kg kg**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Specific Humidity
'kg kg**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}
#2m Relative Humidity
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Relative Humidity
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}
#Total column integrated water vapour
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 54 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Evaporation (s)
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Total Column-Integrated Cloud Ice
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Precipitation rate (S)
'kg m**-2 s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale Precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 62 ;
	 timeRangeIndicator = 4 ;
	}
#Convective Precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow depth water equivalent
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow Depth
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Cloud Cover
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Cloud Cover
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Cover (800 hPa - Soil)
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (400 - 800 hPa)
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cloud Cover (0 - 400 hPa)
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total Column-Integrated Cloud Water
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Snowfall rate water equivalent (s)
'kg m**-2 s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Large-Scale snowfall rate water equivalent (s)
'kg m**-2 s**-1' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Land Cover (1=land, 0=sea)
'(0 - 1)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Surface Roughness length Surface Roughness
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Albedo (in short-wave)
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Soil Temperature  ( 36 cm depth, vv=0h)
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 36 ;
	}
#Soil Temperature (41 cm depth)
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 41 ;
	}
#Soil Temperature
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 9 ;
	}
#Soil Temperature
'K' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#Column-integrated Soil Moisture
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 190 ;
	 topLevel = 100 ;
	}
#Column-integrated Soil Moisture (1) 0 -10 cm
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 10 ;
	}
#Column-integrated Soil Moisture (2) 10-100cm
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 100 ;
	 topLevel = 10 ;
	}
#Plant cover
'%' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 87 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Water Runoff (10-100)
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 timeRangeIndicator = 4 ;
	 topLevel = 10 ;
	 bottomLevel = 100 ;
	}
#Water Runoff (10-190)
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 timeRangeIndicator = 4 ;
	 topLevel = 10 ;
	 bottomLevel = 190 ;
	}
#Water Runoff (s)
'kg m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 112 ;
	 bottomLevel = 10 ;
	 timeRangeIndicator = 4 ;
	 topLevel = 0 ;
	}
#Sea Ice Cover ( 0= free, 1=cover)
'~' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Thickness
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 92 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Significant height of combined wind waves and swell
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 100 ;
	}
#Direction of wind waves
'Degree true' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 101 ;
	}
#Significant height of wind waves
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period of wind waves
's' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell waves
'Degree true' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 104 ;
	}
#Significant height of swell waves
'm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period of swell waves
's' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 106 ;
	}
#Net short wave radiation flux (m) (at the surface)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (at the surface)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Net short wave radiation flux (m) (on the model top)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net short wave radiation flux
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Net long wave radiation flux (m) (on the model top)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}
#Net long wave radiation flux
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 0 ;
	}
#Latent Heat Net Flux (m)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Sensible Heat Net Flux (m)
'W m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, U-Component (m)
'N m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Momentum Flux, V-Component (m)
'N m**-2' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation (m) (at the surface)
'W m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Photosynthetically active radiation
'W m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Solar radiation heating rate
'K s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Thermal radiation heating rate
'K s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Latent heat flux from bare soil
'W m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 18 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Latent heat flux from plants
'W m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 19 ;
	 indicatorOfTypeOfLevel = 111 ;
	 timeRangeIndicator = 3 ;
	}
#Sunshine
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 20 ;
	 timeRangeIndicator = 4 ;
	}
#Stomatal Resistance
's m**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 21 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Cloud cover
'%' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Non-Convective Cloud Cover, grid scale
'%' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Mixing Ratio
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Cloud Ice Mixing Ratio
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Rain mixing ratio
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Snow mixing ratio
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated rain
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Total column integrated snow
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Grauple
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 39 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Total column integrated grauple
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 40 ;
	}
#Total Column integrated water (all components incl. precipitation)
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertical integral of divergence of total water content (s)
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#subgrid scale cloud water
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 43 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#subgridscale cloud ice
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#cloud cover CH (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}
#cloud cover CM (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}
#cloud cover CL (0..8)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}
#cloud base above msl, shallow convection
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#cloud top above msl, shallow convection
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 59 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#specific cloud water content, convective cloud
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Height of Convective Cloud Base (i)
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 2 ;
	}
#Height of Convective Cloud Top (i)
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 3 ;
	}
#base index (vertical level) of main convective cloud (i)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#top index (vertical level) of main convective cloud (i)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to convection
'K s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to convection
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#zonal wind tendency due to convection
'm s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to convection
'm s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#height of top of dry convection
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of 0 degree celsius level code 0,3,6 ?
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Height of snow fall limit
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 4 ;
	}
#Tendency of specific cloud liquid water content due to conversion
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 88 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of  specific cloud ice content due to convection
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 89 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific content of precipitation particles (needed for water loadin)g
'kg kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Large scale rain rate
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale snowfall rate water equivalent
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Large scale rain rate (s)
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Convective rain rate
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective snowfall rate water equivalent
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective rain rate (s)
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#rain amount, grid-scale plus convective
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#snow amount, grid-scale plus convective
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Temperature tendency due to grid scale precipation
'K s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Specific humitiy tendency due to grid scale precipitation
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#tendency of specific cloud liquid water content due to grid scale precipitation
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 127 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 129 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#tendency of specific cloud ice content due to grid scale precipitation
'kg kg**-1 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Graupel (snow pellets) precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Graupel (snow pellets) precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 4 ;
	}
#Snow density
'kg m**-3' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Pressure perturbation
'Pa' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#supercell detection index 1 (rot. up+down drafts)
's**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 141 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#supercell detection index 2 (only rot. up drafts)
's**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 142 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, most unstable
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 143 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, most unstable
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 144 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy, mean layer
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 145 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Inhibition, mean layer
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 146 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective turbulent kinetic enery
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 147 ;
	}
#Tendency of turbulent kinetic energy
'm s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 148 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Kinetic Energy
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 149 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Turbulent Kinetic Energy
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 152 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusioncoefficient for momentum
'm**2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 153 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent diffusion coefficient for heat (and moisture)
'm**2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 109 ;
	}
#Turbulent transfer coefficient for impulse
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 170 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Turbulent transfer coefficient for heat (and Moisture)
'~' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 171 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#mixed layer depth
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 173 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#maximum Wind 10m
'm s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	 timeRangeIndicator = 2 ;
	}
#Air concentration of Ruthenium 103
'Bq m**-3' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 194 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Soil Temperature (multilayers)
'K' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 197 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Column-integrated Soil Moisture (multilayers)
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#soil ice content (multilayers)
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 111 ;
	}
#Plant Canopy Surface Water
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Snow temperature (top of snow)
'K' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Minimal Stomatal Resistance
's m**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 212 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#sea Ice Temperature
'K' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'dB' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Base reflectivity
'dB' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Base reflectivity (cmax)
'dB' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	}
#unknown
'm' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Effective transmissivity of solar radiation
'K s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#sum of contributions to evaporation
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 236 ;
	}
#total transpiration from all soil layers
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 237 ;
	}
#total forcing at soil surface
'W m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 238 ;
	}
#residuum of soil moisture
'kg m**-2' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 239 ;
	}
#Massflux at convective cloud base
'kg m**-2 s**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 240 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Convective Available Potential Energy
'J kg**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#moisture convergence for Kuo-type closure
's**-1' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 243 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#total wave direction
'Degree true' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 4 ;
	}
#wind sea mean period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#wind sea peak period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	}
#swell mean period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 102 ;
	}
#swell peak period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	}
#total wave peak period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 9 ;
	}
#total wave mean period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 10 ;
	}
#total Tm1 period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 17 ;
	}
#total Tm2 period
's' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 18 ;
	}
#total directional spread
'Degree true' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 19 ;
	}
#analysis error(standard deviation), geopotential(gpm)
'gpm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 40 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), u-comp. of wind
'm**2 s**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 41 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#analysis error(standard deviation), v-comp. of wind
'm**2 s**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 42 ;
	 level = 100 ;
	}
#zonal wind tendency due to subgrid scale oro.
'm s**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 44 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#meridional wind tendency due to subgrid scale oro.
'm s**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 45 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Standard deviation of sub-grid scale orography
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 46 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Anisotropy of sub-gridscale orography
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 47 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Angle of sub-gridscale orography
'radians' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 48 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Slope of sub-gridscale orography
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 49 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#surface emissivity
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 56 ;
	 indicatorOfTypeOfLevel = 1 ;
	 level = 0 ;
	 timeRangeIndicator = 0 ;
	}
#Soil Type
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Leaf area index
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#root depth of vegetation
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 62 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#height of ozone maximum (climatological)
'Pa' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 64 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#vertically integrated ozone content (climatological)
'Pa' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 65 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the vegetation phase
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 67 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Plant covering degree in the quiescent phas
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Max Leaf area index
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Min Leaf area index
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 70 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Orographie + Land-Meer-Verteilung
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 71 ;
	}
#variance of soil moisture content (0-10)
'kg**2 m**-4' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 10 ;
	}
#variance of soil moisture content (10-100)
'kg**2 m**-4' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 10 ;
	 bottomLevel = 100 ;
	}
#evergreen forest
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#deciduous forest
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 76 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#normalized differential vegetation index
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 77 ;
	 timeRangeIndicator = 3 ;
	}
#normalized differential vegetation index (NDVI)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 3 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Total sulfate aerosol
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	}
#Total sulfate aerosol (12M)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}
#Total soil dust aerosol
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	}
#Total soil dust aerosol (12M)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	 timeRangeIndicator = 3 ;
	}
#Organic aerosol
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	}
#Organic aerosol (12M)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	 timeRangeIndicator = 3 ;
	}
#Black carbon aerosol
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	}
#Black carbon aerosol (12M)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	 timeRangeIndicator = 3 ;
	}
#Sea salt aerosol
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	}
#Sea salt aerosol (12M)
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	 timeRangeIndicator = 3 ;
	}
#tendency of specific humidity
's**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 104 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#water vapor flux
's**-1 m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 105 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Coriolis parameter
's**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical latitude
'Degree N' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geographical longitude
'Degree E' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 115 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Friction velocity
'm s**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 120 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Delay of the GPS signal trough the (total) atm.
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough wet atmos.
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Delay of the GPS signal trough dry atmos.
'm' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 123 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ozone Mixing Ratio
'kg kg**-1' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 180 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#Air concentration of Ruthenium 103 (Ru103- concentration)
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 194 ;
	}
#Ru103-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 195 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ru103-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Strontium 90
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 197 ;
	}
#Sr90-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Sr90-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-concentration
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 200 ;
	}
#I131-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 201 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 202 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-concentration
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 203 ;
	}
#Cs137-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Cs137-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 205 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Tellurium 132 (Te132-concentration)
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 206 ;
	}
#Te132-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 207 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Te132-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 208 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Zirconium 95 (Zr95-concentration)
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 209 ;
	}
#Zr95-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 210 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Zr95-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 211 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Krypton 85  (Kr85-concentration)
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 212 ;
	}
#Kr85-dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 213 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Kr85-wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 214 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - concentration
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 215 ;
	}
#TRACER - dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 216 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#TRACER - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 217 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Xenon 133 (Xe133  - concentration)
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 218 ;
	}
#Xe133  - dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 219 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Xe133  - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 220 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g - concentration
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 221 ;
	}
#Xe133  - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 222 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131g  - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 223 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - concentration
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 224 ;
	}
#I131o  - dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 225 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#I131o  - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 226 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Air concentration of Barium 40
'Bq m**-3' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 227 ;
	}
#Ba140 - dry deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 228 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Ba140  - wet deposition
'Bq m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 229 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#u-momentum flux due to SSO-effects
'N m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#u-momentum flux due to SSO-effects
'N m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#v-momentum flux due to SSO-effects
'N m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#v-momentum flux due to SSO-effects
'N m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#Gravity wave dissipation (vertical integral)
'W m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}
#Gravity wave dissipation (vertical integral)
'W m**-2' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}
#UV_Index_Maximum_W  UV_Index clouded (W), daily maximum
'~' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 248 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#wind shear
'm s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 29 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#storm relative helicity
'J kg**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 30 ;
	 indicatorOfTypeOfLevel = 110 ;
	}
#absolute vorticity advection
's**-2' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#NiederschlagBew.-ArtKombination Niederschl.-Bew.-Blautherm. (283..407)
'~' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 90 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konvektions-U-GrenzeHoehe der Konvektionsuntergrenze ueber Grund
'm' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Konv.-U-Grenze-nn   Hoehe der Konvektionsuntergrenze ueber nn
'm' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 94 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#weather interpretation (WMO)
'~' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 99 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#geostrophische  Vorticityadvektion
's**-2' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 101 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Geo Temperatur Adv  geostrophische Schichtdickenadvektion
'm**3 kg**-1 s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 103 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Schichtdicken-Advektion
'm**3 kg**-1 s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 107 ;
	 indicatorOfTypeOfLevel = 101 ;
	}
#Winddivergenz
's**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 109 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Qn-Vektor Q isother-senkr-KompQn ,Komp. Q-Vektor senkrecht zu den Isothermen
'm**2 kg**-1 s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Isentrope potentielle Vorticity
'K m**2 kg**-1 s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#XIPV Wind X-Komp     Wind X-Komponente auf isentropen Flaechen
'm s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 131 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#YIPV Wind Y-Komp     Wind Y-Komponente auf isentropen Flaechen
'm s**-1' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 132 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Druck einer isentropen Flaeche
'Pa' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#KO index
'K' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 140 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Aequivalentpotentielle Temperatur
'K' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 154 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#Ceiling
'm' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 157 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Icing Grade (1=LGT,2=MOD,3=SEV)
'~' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 196 ;
	 indicatorOfTypeOfLevel = 100 ;
	}
#modified cloud depth for media
'~' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 203 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#modified cloud cover for media
'~' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 204 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'Pa' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 1 ;
	}
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'Pa' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 2 ;
	}
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'm s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 3 ;
	}
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'm s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 4 ;
	}
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'm s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 5 ;
	}
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'm s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 6 ;
	}
#Monthly Mean of RMS of difference FG-AN of geopotential
'm**2 s**-2' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 7 ;
	}
#Monthly Mean of RMS of difference IA-AN of geopotential
'm**2 s**-2' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 8 ;
	}
#Monthly Mean of RMS of difference FG-AN of relative humidity
'%' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 9 ;
	}
#Monthly Mean of RMS of difference IA-AN of relative humidity
'%' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 10 ;
	}
#Monthly Mean of RMS of difference FG-AN of temperature
'K' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 11 ;
	}
#Monthly Mean of RMS of difference IA-AN of temperature
'K' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 12 ;
	}
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'Pa s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 13 ;
	}
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'Pa s**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 14 ;
	}
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'J kg**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 15 ;
	}
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'J kg**-1' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 16 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature cloudy
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 1 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. brightness temperature clear sky
'K' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 2 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance cloudy
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 3 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	 localElementNumber = 4 ;
	}
#Synth. Sat. radiance clear sky
'W m sr m**-2' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	 localElementNumber = 4 ;
	}
#smoothed forecast, temperature
'K' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, maximum temp.
'K' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, minimum temp.
'K' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	 timeRangeIndicator = 2 ;
	}
#smoothed forecast, dew point temp.
'K' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#smoothed forecast, u comp. of wind
'm s**-1' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, v comp. of wind
'm s**-1' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#smoothed forecast, total precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, total cloud cover
'%' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 71 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover low
'%' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover medium
'%' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, cloud cover high
'%' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, large-scale snowfall rate w.e.
'kg m**-2 s**-1' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#smoothed forecast, soil temperature
'K' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}
#smoothed forecast, wind speed (gust)
'm s**-1' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#calibrated forecast, total precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 61 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, large-scale snowfall rate w.e.
'kg m**-2 s**-1' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 79 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#calibrated forecast, wind speed (gust)
'm s**-1' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
}
