# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.76, Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents with source/sink
include "grib2/template.4.parameter_chemical_source.def";
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def";
