# Automatically generated by ./create_def.pl, do not edit
#Total precipitation of at least 1 mm
'Total precipitation of at least 1 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 1 ;
	}
#Total precipitation of at least 5 mm
'Total precipitation of at least 5 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 5 ;
	 productDefinitionTemplateNumber = 9 ;
	}
#Total precipitation of at least 40 mm
'Total precipitation of at least 40 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 40 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total precipitation of at least 60 mm
'Total precipitation of at least 60 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaleFactorOfLowerLimit = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfLowerLimit = 60 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total precipitation of at least 80 mm
'Total precipitation of at least 80 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 80 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total precipitation of at least 100 mm
'Total precipitation of at least 100 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 100 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total precipitation of at least 150 mm
'Total precipitation of at least 150 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaledValueOfLowerLimit = 150 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	}
#Total precipitation of at least 200 mm
'Total precipitation of at least 200 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 200 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total precipitation of at least 300 mm
'Total precipitation of at least 300 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 probabilityType = 3 ;
	 scaledValueOfLowerLimit = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 productDefinitionTemplateNumber = 9 ;
	 scaleFactorOfLowerLimit = -2 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 103 ;
	 is_uerra = 1 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 is_uerra = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Unbalanced component of temperature
'Unbalanced component of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Unbalanced component of logarithm of surface pressure
'Unbalanced component of logarithm of surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 31 ;
	}
#Unbalanced component of divergence
'Unbalanced component of divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 45 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Snow density
'Snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}
#Sea surface temperature
'Sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil type
'Soil type' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#10 metre wind gust since previous post-processing
'10 metre wind gust since previous post-processing' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 is_uerra = 1 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Specific rain water content
'Specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	}
#Specific snow water content
'Specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	}
#Eta-coordinate vertical velocity
'Eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	}
#Total column cloud liquid water
'Total column cloud liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column cloud ice water
'Total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Surface solar radiation downwards
'Surface solar radiation downwards' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface thermal radiation downwards
'Surface thermal radiation downwards' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Top net solar radiation
'Top net solar radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Eastward turbulent surface stress
'Eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 38 ;
	}
#Northward turbulent surface stress
'Northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 37 ;
	}
#Maximum temperature at 2 metres since previous post-processing
'Maximum temperature at 2 metres since previous post-processing' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 is_uerra = 1 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Minimum temperature at 2 metres since previous post-processing
'Minimum temperature at 2 metres since previous post-processing' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 is_uerra = 1 ;
	}
#Ozone mass mixing ratio
'Ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}
#Surface net solar radiation, clear sky
'Surface net solar radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net thermal radiation, clear sky
'Surface net thermal radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Temperature of snow layer
'Temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Specific cloud liquid water content
'Specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	}
#Specific cloud ice water content
'Specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	}
#Fraction of cloud cover
'Fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	}
#large scale precipitation
'large scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow depth
'Snow depth' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Low cloud cover
'Low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	}
#Medium cloud cover
'Medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	}
#High cloud cover
'High cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	}
#Total precipitation of at least 25 mm
'Total precipitation of at least 25 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 25 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total precipitation of at least 50 mm
'Total precipitation of at least 50 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 50 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#10 metre wind gust of at least 10 m/s
'10 metre wind gust of at least 10 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 10 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Probability of temperature standardized anomaly greater than 1 standard deviation
'Probability of temperature standardized anomaly greater than 1 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 scaledValueOfLowerLimit = 1 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	}
#Probability of temperature standardized anomaly greater than 1.5 standard deviation
'Probability of temperature standardized anomaly greater than 1.5 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 scaleFactorOfLowerLimit = 1 ;
	 scaledValueOfLowerLimit = 15 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 10 ;
	}
#Probability of temperature standardized anomaly greater than 2 standard deviation
'Probability of temperature standardized anomaly greater than 2 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = 2 ;
	}
#Probability of temperature standardized anomaly less than -1 standard deviation
'Probability of temperature standardized anomaly less than -1 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 probabilityType = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = -1 ;
	 productDefinitionTemplateNumber = 9 ;
	}
#Probability of temperature standardized anomaly less than -1.5 standard deviation
'Probability of temperature standardized anomaly less than -1.5 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaleFactorOfLowerLimit = 1 ;
	 scaledValueOfLowerLimit = -15 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 0 ;
	}
#Probability of temperature standardized anomaly less than -2 standard deviation
'Probability of temperature standardized anomaly less than -2 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaledValueOfLowerLimit = -2 ;
	 productDefinitionTemplateNumber = 9 ;
	 probabilityType = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	}
#Mean sea water potential temperature in the upper 300 m
'Mean sea water potential temperature in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Mean sea water temperature in the upper 300 m
'Mean sea water temperature in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Sea surface practical salinity
'Sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Ocean mixed layer thickness defined by sigma theta 0.01 kg/m3
'Ocean mixed layer thickness defined by sigma theta 0.01 kg/m3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#2 metre specific humidity
'2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Ammonium aerosol mass mixing ratio
'Ammonium aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 is_aerosol = 1 ;
	 aerosolType = 62003 ;
	}
#Nitrate aerosol optical depth at 550 nm
'Nitrate aerosol optical depth at 550 nm' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfWavelengthInterval = 11 ;
	 aerosolType = 62004 ;
	 typeOfSizeInterval = 255 ;
	 scaleFactorOfFirstWavelength = 8 ;
	 is_aerosol_optical = 1 ;
	 scaledValueOfFirstWavelength = 55 ;
	}
#Ammonium aerosol optical depth at 550 nm
'Ammonium aerosol optical depth at 550 nm' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 scaledValueOfFirstWavelength = 55 ;
	 typeOfWavelengthInterval = 11 ;
	 aerosolType = 62003 ;
	 scaleFactorOfFirstWavelength = 8 ;
	 is_aerosol_optical = 1 ;
	 typeOfSizeInterval = 255 ;
	}
#Ammonium aerosol mass mixing ratio
'Ammonium aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Dry deposition of ammonium aerosol
'Dry deposition of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Sedimentation of ammonium aerosol
'Sedimentation of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of ammonium aerosol by large-scale precipitation
'Wet deposition of ammonium aerosol by large-scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 is_aerosol = 1 ;
	 aerosolType = 62003 ;
	}
#Wet deposition of ammonium aerosol by convective precipitation
'Wet deposition of ammonium aerosol by convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Vertically integrated mass of ammonium aerosol
'Vertically integrated mass of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#-10 degrees C isothermal level (atm)
'-10 degrees C isothermal level (atm)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#0 degrees C isothermal level (atm)
'0 degrees C isothermal level (atm)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#10 metre wind gust in the last 3 hours
'10 metre wind gust in the last 3 hours' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 is_uerra = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 lengthOfTimeRange = 3 ;
	}
#Relative humidity with respect to water
'Relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	}
#Relative humidity with respect to ice
'Relative humidity with respect to ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}
#Snow albedo
'Snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	}
#Fraction of stratiform precipitation cover
'Fraction of stratiform precipitation cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	}
#Fraction of convective precipitation cover
'Fraction of convective precipitation cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 37 ;
	}
#Maximum CAPE in the last 6 hours
'Maximum CAPE in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 8 ;
	 lengthOfTimeRange = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	}
#Maximum CAPES in the last 6 hours
'Maximum CAPES in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 lengthOfTimeRange = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#2 metre relative humidity with respect to water
'2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Liquid water content in snow pack
'Liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}
#Height of convective cloud top
'Height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	}
#Instantaneous total lightning flash density
'Instantaneous total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Averaged total lightning flash density in the last hour
'Averaged total lightning flash density in the last hour' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 8 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 lengthOfTimeRange = 1 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'Instantaneous cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Averaged cloud-to-ground lightning flash density in the last hour
'Averaged cloud-to-ground lightning flash density in the last hour' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 lengthOfTimeRange = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Unbalanced component of specific humidity
'Unbalanced component of specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 118 ;
	}
#Unbalanced component of specific cloud liquid water content
'Unbalanced component of specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 119 ;
	}
#Unbalanced component of specific cloud ice water content
'Unbalanced component of specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 120 ;
	}
#Averaged total lightning flash density in the last 3 hours
'Averaged total lightning flash density in the last 3 hours' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	 lengthOfTimeRange = 3 ;
	}
#Averaged total lightning flash density in the last 6 hours
'Averaged total lightning flash density in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 lengthOfTimeRange = 6 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 3 hours
'Averaged cloud-to-ground lightning flash density in the last 3 hours' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 lengthOfTimeRange = 3 ;
	 typeOfSecondFixedSurface = 8 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 6 hours
'Averaged cloud-to-ground lightning flash density in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	 lengthOfTimeRange = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil moisture top 20 cm
'Soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Soil moisture top 100 cm
'Soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Soil temperature top 20 cm
'Soil temperature top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	}
#Soil temperature top 100 cm
'Soil temperature top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Convective precipitation
'Convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Water runoff and drainage
'Water runoff and drainage' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}
#Mixed-layer CAPE in the lowest 50 hPa
'Mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 50 hPa
'Mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CAPE in the lowest 100 hPa
'Mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 100 hPa
'Mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Most-unstable CAPE
'Most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Most-unstable CIN
'Most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Departure level of the most unstable parcel expressed as Pressure
'Departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#200 metre U wind component
'200 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#200 metre V wind component
'200 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#200 metre wind speed
'200 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 200 ;
	}
#100 metre wind speed
'100 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mean temperature tendency due to short-wave radiation
'Mean temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean temperature tendency due to long-wave radiation
'Mean temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean temperature tendency due to short-wave radiation, clear sky
'Mean temperature tendency due to short-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean temperature tendency due to long-wave radiation, clear sky
'Mean temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean temperature tendency due to parametrisations
'Mean temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean specific humidity tendency due to parametrisations
'Mean specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean eastward wind tendency due to parametrisations
'Mean eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean northward wind tendency due to parametrisations
'Mean northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean updraught mass flux
'Mean updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean downdraught mass flux
'Mean downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean updraught detrainment rate
'Mean updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean downdraught detrainment rate
'Mean downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean total precipitation flux
'Mean total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean turbulent diffusion coefficient for heat
'Mean turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of rain flux
'Time integral of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface eastward momentum flux
'Time integral of surface eastward momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface northward momentum flux
'Time integral of surface northward momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Cross sectional area of flow in channel
'Cross sectional area of flow in channel' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Side flow into river channel
'Side flow into river channel' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Discharge from rivers or streams
'Discharge from rivers or streams' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#River storage of water
'River storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Floodplain storage of water
'Floodplain storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Water fraction
'Water fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Days since last observation
'Days since last observation' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 3 ;
	}
#Frost index
'Frost index' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}
#Depth of water on soil surface
'Depth of water on soil surface' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Upstream accumulated precipitation
'Upstream accumulated precipitation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Upstream accumulated snow melt
'Upstream accumulated snow melt' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Mean discharge in the last 6 hours
'Mean discharge in the last 6 hours' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 lengthOfTimeRange = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean discharge in the last 24 hours
'Mean discharge in the last 24 hours' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 lengthOfTimeRange = 24 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow depth at elevation bands
'Snow depth at elevation bands' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}
#Groundwater upper storage
'Groundwater upper storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Groundwater lower storage
'Groundwater lower storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Latitude
'Latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}
#Longitude
'Longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}
#Latitude on T grid
'Latitude on T grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Longitude on T grid
'Longitude on T grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Latitude on U grid
'Latitude on U grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Longitude on U grid
'Longitude on U grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Latitude on V grid
'Latitude on V grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Longitude on V grid
'Longitude on V grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Latitude on W grid
'Latitude on W grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Longitude on W grid
'Longitude on W grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Latitude on F grid
'Latitude on F grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Longitude on F grid
'Longitude on F grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Total column graupel
'Total column graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#2 metre relative humidity
'2 metre relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Apparent temperature
'Apparent temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Haines Index
'Haines Index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Cloud cover
'Cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}
#Evaporation rate
'Evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	}
#Evaporation
'Evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#10 metre wind direction
'10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Direct short wave radiation flux
'Direct short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	}
#Diffuse short wave radiation flux
'Diffuse short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}
#Time-integrated surface direct short wave radiation flux
'Time-integrated surface direct short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Evaporation in the last 6 hours
'Evaporation in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 lengthOfTimeRange = 6 ;
	 is_uerra = 0 ;
	}
#Evaporation in the last 24 hours
'Evaporation in the last 24 hours' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 is_uerra = 0 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Total precipitation in the last 6 hours
'Total precipitation in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 is_efas = 1 ;
	 lengthOfTimeRange = 6 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total precipitation in the last 24 hours
'Total precipitation in the last 24 hours' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 is_efas = 1 ;
	 lengthOfTimeRange = 24 ;
	}
#Fraction of snow cover
'Fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	}
#Clear air turbulence (CAT)
'Clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	}
#Mountain wave turbulence (eddy dissipation rate)
'Mountain wave turbulence (eddy dissipation rate)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 28 ;
	}
#Soil temperature
'Soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#Downward short-wave radiation flux, clear sky
'Downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	}
#Upward short-wave radiation flux, clear sky
'Upward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	}
#Downward long-wave radiation flux, clear sky
'Downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	}
#Soil heat flux
'Soil heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}
#Percolation rate
'Percolation rate' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Soil depth
'Soil depth' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	}
#Accumulated surface downward short-wave radiation flux, clear sky
'Accumulated surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Accumulated surface upward short-wave radiation flux, clear sky
'Accumulated surface upward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Accumulated surface downward long-wave radiation flux, clear sky
'Accumulated surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Percolation
'Percolation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 177 ;
	}
#Cloudy brightness temperature
'Cloudy brightness temperature' = {
         discipline = 3 ;
         parameterCategory = 1 ;
         parameterNumber = 14 ;
        }
#Clear-sky brightness temperature
'Clear-sky brightness temperature' = {
         discipline = 3 ;
         parameterCategory = 1 ;
         parameterNumber = 15 ;
        }
#Scaled radiance
'Scaled radiance' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Scaled albedo
'Scaled albedo' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Scaled brightness temperature
'Scaled brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Scaled precipitable water
'Scaled precipitable water' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Scaled lifted index
'Scaled lifted index' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Scaled cloud top pressure
'Scaled cloud top pressure' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Scaled skin temperature
'Scaled skin temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Cloud mask
'Cloud mask' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Pixel scene type
'Pixel scene type' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Fire detection indicator
'Fire detection indicator' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Forest fire weather index
'Forest fire weather index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Fine fuel moisture code
'Fine fuel moisture code' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Duff moisture code
'Duff moisture code' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Drought code
'Drought code' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	}
#Initial fire spread index
'Initial fire spread index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	}
#Fire buildup index
'Fire buildup index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	}
#Fire daily severity rating
'Fire daily severity rating' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}
#Cloudy radiance (with respect to wave number)
'Cloudy radiance (with respect to wave number)' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	}
#Clear-sky radiance (with respect to wave number)
'Clear-sky radiance (with respect to wave number)' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Aerosol optical thickness at 0.635 um
'Aerosol optical thickness at 0.635 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Aerosol optical thickness at 0.810 um
'Aerosol optical thickness at 0.810 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Aerosol optical thickness at 1.640 um
'Aerosol optical thickness at 1.640 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Angstrom coefficient
'Angstrom coefficient' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Keetch-Byram drought index
'Keetch-Byram drought index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#Drought factor (as defined by the Australian forest service)
'Drought factor (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	}
#Rate of spread (as defined by the Australian forest service)
'Rate of spread (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}
#Fire danger index (as defined by the Australian forest service)
'Fire danger index (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	}
#Spread component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Spread component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}
#Burning index (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Burning index (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 17 ;
	}
#Ignition component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Ignition component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}
#Energy release component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Energy release component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}
#Universal thermal climate index
'Universal thermal climate index' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Mean radiant temperature
'Mean radiant temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Fraction of Malaria cases
'Fraction of Malaria cases' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Malaria circumsporozoite protein ratio
'Malaria circumsporozoite protein ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Plasmodium falciparum entomological inoculation rate
'Plasmodium falciparum entomological inoculation rate' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Human bite rate by anopheles vectors
'Human bite rate by anopheles vectors' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Malaria immunity ratio
'Malaria immunity ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Falciparum parasite ratio
'Falciparum parasite ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Detectable falciparum parasite ratio (after day 10)
'Detectable falciparum parasite ratio (after day 10)' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Anopheles vector to host ratio
'Anopheles vector to host ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Anopheles vector density
'Anopheles vector density' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Fraction of malarial vector reproductive habitat
'Fraction of malarial vector reproductive habitat' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Population density
'Population density' = {
	 discipline = 20 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Virtual temperature
'Virtual temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Virtual potential temperature
'Virtual potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Pseudo-adiabatic potential temperature
'Pseudo-adiabatic potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Wind direction
'Wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Mean zero-crossing wave period
'Mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Mean wave direction
'Mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Peak wave period
'Peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Mean wave period
'Mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Eastward sea water velocity
'Eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 160 ;
	}
#Northward sea water velocity
'Northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 160 ;
	}
#Sea surface height
'Sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Depth of 20C isotherm
'Depth of 20C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Average salinity in the upper 300m
'Average salinity in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfSecondFixedSurface = 160 ;
	 typeOfFirstFixedSurface = 160 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Surface runoff
'Surface runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Sea-ice thickness
'Sea-ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#100 metre U wind component
'100 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#100 metre V wind component
'100 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Total precipitation of at least 10 mm
'Total precipitation of at least 10 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 10 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	}
#Total precipitation of at least 20 mm
'Total precipitation of at least 20 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaleFactorOfLowerLimit = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 probabilityType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 productDefinitionTemplateNumber = 9 ;
	}
#Stream function
'Stream function' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}
#Velocity potential
'Velocity potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}
#Potential temperature
'Potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Pressure
'Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Convective available potential energy
'Convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Potential vorticity
'Potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'Maximum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 is_uerra = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'Minimum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 is_uerra = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#Geopotential
'Geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Temperature
'Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#U component of wind
'U component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#V component of wind
'V component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Specific humidity
'Specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Surface pressure
'Surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Vertical velocity
'Vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Total column water
'Total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Vorticity (relative)
'Vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}
#Boundary layer dissipation
'Boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}
#Surface sensible heat flux
'Surface sensible heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface latent heat flux
'Surface latent heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Mean sea level pressure
'Mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#Divergence
'Divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Geopotential Height
'Geopotential Height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Relative humidity
'Relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#10 metre U wind component
'10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#10 metre V wind component
'10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}
#Land-sea mask
'Land-sea mask' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness
'Surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Surface net solar radiation
'Surface net solar radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net thermal radiation
'Surface net thermal radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Top net thermal radiation
'Top net thermal radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Sunshine duration
'Sunshine duration' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Brightness temperature
'Brightness temperature' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}
#10 metre wind speed
'10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#Skin temperature
'Skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Latent heat net flux
'Latent heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Sensible heat net flux
'Sensible heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Heat index
'Heat index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Wind chill factor
'Wind chill factor' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Minimum dew point depression
'Minimum dew point depression' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Snow phase change heat flux
'Snow phase change heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Vapor pressure
'Vapor pressure' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Large scale precipitation (non-convective)
'Large scale precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Snowfall rate water equivalent
'Snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Convective snow
'Convective snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}
#Large scale snow
'Large scale snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}
#Snow age
'Snow age' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Absolute humidity
'Absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}
#Precipitation type
'Precipitation type' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Integrated liquid water
'Integrated liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Condensate
'Condensate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Cloud mixing ratio
'Cloud mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Ice water mixing ratio
'Ice water mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Rain mixing ratio
'Rain mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}
#Snow mixing ratio
'Snow mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}
#Horizontal moisture convergence
'Horizontal moisture convergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}
#Maximum relative humidity
'Maximum relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}
#Maximum absolute humidity
'Maximum absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}
#Total snowfall
'Total snowfall' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 29 ;
	}
#Precipitable water category
'Precipitable water category' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}
#Hail
'Hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}
#Graupel (snow pellets)
'Graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}
#Categorical rain
'Categorical rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}
#Categorical freezing rain
'Categorical freezing rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}
#Categorical ice pellets
'Categorical ice pellets' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}
#Categorical snow
'Categorical snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}
#Convective precipitation rate
'Convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	}
#Horizontal moisture divergence
'Horizontal moisture divergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 38 ;
	}
#Percent frozen precipitation
'Percent frozen precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}
#Potential evaporation
'Potential evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}
#Potential evaporation rate
'Potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 41 ;
	}
#Snow cover
'Snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}
#Rain fraction of total cloud water
'Rain fraction of total cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}
#Rime factor
'Rime factor' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}
#Total column integrated rain
'Total column integrated rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}
#Total column integrated snow
'Total column integrated snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}
#Large scale water precipitation (non-convective)
'Large scale water precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}
#Convective water precipitation
'Convective water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}
#Total water precipitation
'Total water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}
#Total snow precipitation
'Total snow precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 50 ;
	}
#Total column water (Vertically integrated total water (vapour + cloud water/ice))
'Total column water (Vertically integrated total water (vapour + cloud water/ice))' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}
#Total precipitation rate
'Total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}
#Total snowfall rate water equivalent
'Total snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	}
#Large scale precipitation rate
'Large scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	}
#Convective snowfall rate water equivalent
'Convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	}
#Large scale snowfall rate water equivalent
'Large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	}
#Total snowfall rate
'Total snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 57 ;
	}
#Convective snowfall rate
'Convective snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}
#Large scale snowfall rate
'Large scale snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'Water equivalent of accumulated snow depth (deprecated)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Total column integrated water vapour
'Total column integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	}
#Rain precipitation rate
'Rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	}
#Snow precipitation rate
'Snow precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	}
#Freezing rain precipitation rate
'Freezing rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	}
#Ice pellets precipitation rate
'Ice pellets precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}
#Momentum flux, u component
'Momentum flux, u component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	}
#Momentum flux, v component
'Momentum flux, v component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	}
#Maximum wind speed
'Maximum wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}
#Wind speed (gust)
'Wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	}
#u-component of wind (gust)
'u-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}
#v-component of wind (gust)
'v-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}
#Vertical speed shear
'Vertical speed shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}
#Horizontal momentum flux
'Horizontal momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}
#U-component storm motion
'U-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}
#V-component storm motion
'V-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}
#Drag coefficient
'Drag coefficient' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}
#Frictional velocity
'Frictional velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}
#Pressure reduced to MSL
'Pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Geometric height
'Geometric height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Altimeter setting
'Altimeter setting' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Thickness
'Thickness' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Pressure altitude
'Pressure altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Density altitude
'Density altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#5-wave geopotential height
'5-wave geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Zonal flux of gravity wave stress
'Zonal flux of gravity wave stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}
#Meridional flux of gravity wave stress
'Meridional flux of gravity wave stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}
#Planetary boundary layer height
'Planetary boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#5-wave geopotential height anomaly
'5-wave geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}
#Standard deviation of sub-grid scale orography
'Standard deviation of sub-grid scale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}
#Net short-wave radiation flux (top of atmosphere)
'Net short-wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Downward short-wave radiation flux
'Downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Upward short-wave radiation flux
'Upward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	}
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	}
#Photosynthetically active radiation
'Photosynthetically active radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	}
#Net short-wave radiation flux, clear sky
'Net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}
#Downward UV radiation
'Downward UV radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#UV index (under clear sky)
'UV index (under clear sky)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	}
#UV index 
'UV index ' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	}
#Net long wave radiation flux (surface)
'Net long wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}
#Net long wave radiation flux (top of atmosphere)
'Net long wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}
#Downward long-wave radiation flux
'Downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	}
#Upward long-wave radiation flux
'Upward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	}
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	}
#Net long-wave radiation flux, clear sky
'Net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	}
#Cloud Ice
'Cloud Ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}
#Cloud water
'Cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}
#Cloud amount
'Cloud amount' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}
#Cloud type
'Cloud type' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}
#Thunderstorm maximum tops
'Thunderstorm maximum tops' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}
#Thunderstorm coverage
'Thunderstorm coverage' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}
#Cloud base
'Cloud base' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	}
#Cloud top
'Cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}
#Ceiling
'Ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}
#Non-convective cloud cover
'Non-convective cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}
#Cloud work function
'Cloud work function' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}
#Convective cloud efficiency
'Convective cloud efficiency' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}
#Total condensate
'Total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}
#Total column-integrated cloud water
'Total column-integrated cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}
#Total column-integrated cloud ice
'Total column-integrated cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}
#Total column-integrated condensate
'Total column-integrated condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}
#Ice fraction of total condensate
'Ice fraction of total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}
#Cloud ice mixing ratio
'Cloud ice mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}
#Sunshine
'Sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	}
#Horizontal extent of cumulonimbus (CB)
'Horizontal extent of cumulonimbus (CB)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}
#K index
'K index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}
#KO index
'KO index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}
#Total totals index
'Total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}
#Sweat index
'Sweat index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}
#Storm relative helicity
'Storm relative helicity' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}
#Energy helicity index
'Energy helicity index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}
#Surface lifted index
'Surface lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}
#Best (4-layer) lifted index
'Best (4-layer) lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}
#Aerosol type
'Aerosol type' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}
#Total ozone
'Total ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	}
#Total column integrated ozone
'Total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	}
#Base spectrum width
'Base spectrum width' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}
#Base radial velocity
'Base radial velocity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}
#Vertically-integrated liquid
'Vertically-integrated liquid' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}
#Layer-maximum base reflectivity
'Layer-maximum base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}
#Precipitation
'Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 5 ;
	}
#Air concentration of Caesium 137
'Air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}
#Air concentration of Iodine 131
'Air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}
#Air concentration of radioactive pollutant
'Air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}
#Ground deposition of Caesium 137
'Ground deposition of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}
#Ground deposition of Iodine 131
'Ground deposition of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}
#Ground deposition of radioactive pollutant
'Ground deposition of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}
#Time-integrated air concentration of caesium pollutant
'Time-integrated air concentration of caesium pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}
#Time-integrated air concentration of iodine pollutant
'Time-integrated air concentration of iodine pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}
#Time-integrated air concentration of radioactive pollutant
'Time-integrated air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}
#Volcanic ash
'Volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}
#Icing top
'Icing top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}
#Icing base
'Icing base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}
#Icing
'Icing' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}
#Turbulence top
'Turbulence top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}
#Turbulence base
'Turbulence base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}
#Turbulence
'Turbulence' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}
#Turbulent kinetic energy
'Turbulent kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}
#Planetary boundary layer regime
'Planetary boundary layer regime' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}
#Contrail intensity
'Contrail intensity' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}
#Contrail engine type
'Contrail engine type' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}
#Contrail top
'Contrail top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}
#Contrail base
'Contrail base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}
#Maximum snow albedo
'Maximum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}
#Snow free albedo
'Snow free albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}
#Icing
'Icing' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}
#In-cloud turbulence
'In-cloud turbulence' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}
#Relative clear air turbulence (RCAT)
'Relative clear air turbulence (RCAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}
#Supercooled large droplet probability (see Note 4)
'Supercooled large droplet probability (see Note 4)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}
#Arbitrary text string
'Arbitrary text string' = {
	 discipline = 0 ;
	 parameterCategory = 190 ;
	 parameterNumber = 0 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref
'Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Remotely sensed snow cover
'Remotely sensed snow cover' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Elevation of snow covered terrain
'Elevation of snow covered terrain' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Snow water equivalent percent of normal
'Snow water equivalent percent of normal' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Baseflow-groundwater runoff
'Baseflow-groundwater runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Storm surface runoff
'Storm surface runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th
'Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Probability of 0.01 inch of precipitation (POP)
'Probability of 0.01 inch of precipitation (POP)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Land cover (1=land, 0=sea)
'Land cover (1=land, 0=sea)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Vegetation
'Vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Water runoff
'Water runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Evapotranspiration
'Evapotranspiration' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Model terrain height
'Model terrain height' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Land use
'Land use' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Volumetric soil moisture content
'Volumetric soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Ground heat flux
'Ground heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Moisture availability
'Moisture availability' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Exchange coefficient
'Exchange coefficient' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Plant canopy surface water
'Plant canopy surface water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Blackadar mixing length scale
'Blackadar mixing length scale' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Canopy conductance
'Canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Minimal stomatal resistance
'Minimal stomatal resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Solar parameter in canopy conductance
'Solar parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}
#Temperature parameter in canopy conductance
'Temperature parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}
#Soil moisture parameter in canopy conductance
'Soil moisture parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#Humidity parameter in canopy conductance
'Humidity parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Column-integrated soil water
'Column-integrated soil water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Heat flux
'Heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Volumetric soil moisture
'Volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Volumetric wilting point
'Volumetric wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Upper layer soil temperature
'Upper layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Upper layer soil moisture
'Upper layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#Lower layer soil moisture
'Lower layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Bottom layer soil temperature
'Bottom layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Number of soil layers in root zone
'Number of soil layers in root zone' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Volumetric transpiration stress-onset (soil moisture)
'Volumetric transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Volumetric direct evaporation cease (soil moisture)
'Volumetric direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Volumetric saturation of soil moisture
'Volumetric saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}
#Saturation of soil moisture
'Saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}
#Estimated precipitation
'Estimated precipitation' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Instantaneous rain rate
'Instantaneous rain rate' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Cloud top height
'Cloud top height' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Cloud top height quality indicator
'Cloud top height quality indicator' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Estimated u component of wind 
'Estimated u component of wind ' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Estimated v component of wind
'Estimated v component of wind' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Number of pixels used
'Number of pixels used' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Solar zenith angle
'Solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Relative azimuth angle
'Relative azimuth angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Reflectance in 0.6 micron channel
'Reflectance in 0.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Reflectance in 0.8 micron channel
'Reflectance in 0.8 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Reflectance in 1.6 micron channel
'Reflectance in 1.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Reflectance in 3.9 micron channel
'Reflectance in 3.9 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Atmospheric divergence
'Atmospheric divergence' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Direction of wind waves
'Direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Primary wave direction
'Primary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Primary wave mean period
'Primary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Secondary wave mean period
'Secondary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Current direction
'Current direction' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Current speed
'Current speed' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Geometric vertical velocity
'Geometric vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}
#Ice temperature
'Ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Deviation of sea level from mean
'Deviation of sea level from mean' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#Albedo
'Albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}
#Pressure tendency
'Pressure tendency' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Geometrical height
'Geometrical height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Standard deviation of height
'Standard deviation of height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Maximum temperature
'Maximum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Minimum temperature
'Minimum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Dew point temperature
'Dew point temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Lapse rate
'Lapse rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Visibility
'Visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}
#Radar spectra (1)
'Radar spectra (1)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	}
#Radar spectra (2)
'Radar spectra (2)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}
#Radar spectra (3)
'Radar spectra (3)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}
#Temperature anomaly
'Temperature anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Pressure anomaly
'Pressure anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Wave spectra (1)
'Wave spectra (1)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Wave spectra (2)
'Wave spectra (2)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Wave spectra (3)
'Wave spectra (3)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Montgomery stream Function
'Montgomery stream Function' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Absolute vorticity
'Absolute vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Absolute divergence
'Absolute divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}
#Vertical u-component shear
'Vertical u-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}
#Vertical v-component shear
'Vertical v-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}
#U-component of current 
'U-component of current ' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#V-component of current 
'V-component of current ' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Precipitable water
'Precipitable water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Saturation deficit
'Saturation deficit' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Precipitation rate
'Precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Thunderstorm probability
'Thunderstorm probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Mixed layer depth
'Mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}
#Transient thermocline depth
'Transient thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Main thermocline depth
'Main thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}
#Main thermocline anomaly
'Main thermocline anomaly' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}
#Soil moisture content
'Soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Salinity
'Salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Density
'Density' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Ice thickness
'Ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Direction of ice drift
'Direction of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Speed of ice drift
'Speed of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#U-component of ice drift
'U-component of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}
#V-component of ice drift
'V-component of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}
#Ice growth rate
'Ice growth rate' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Ice divergence
'Ice divergence' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Snow melt
'Snow melt' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	}
#Significant height of wind waves
'Significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Mean period of wind waves
'Mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Direction of swell waves
'Direction of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Significant height of swell waves
'Significant height of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Mean period of swell waves
'Mean period of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Secondary wave direction
'Secondary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Net short-wave radiation flux (surface)
'Net short-wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}
#Global radiation flux
'Global radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Wind mixing energy
'Wind mixing energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}
#10 metre wind gust of at least 15 m/s
'10 metre wind gust of at least 15 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 probabilityType = 3 ;
	 productDefinitionTemplateNumber = 9 ;
	 scaleFactorOfLowerLimit = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}
#10 metre wind gust of at least 20 m/s
'10 metre wind gust of at least 20 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 productDefinitionTemplateNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfLowerLimit = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 probabilityType = 3 ;
	}
#Convective inhibition
'Convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Orography
'Orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil Moisture
'Soil Moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#Soil Moisture
'Soil Moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 is_tigge = 1 ;
	}
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 is_tigge = 1 ;
	}
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}
#Snow Fall water equivalent
'Snow Fall water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Field capacity
'Field capacity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Wilting point
'Wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	}
#Total Precipitation
'Total Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
}
