# Automatically generated by ./create_def.pl, do not edit
#Pressure
'Pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 1 ;
	}
#Pressure reduced to msl
'Pressure reduced to msl' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 2 ;
	}
#Pressure tendency
'Pressure tendency' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 3 ;
	}
#Geopotential
'Geopotential' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 6 ;
	}
#Geopotential height
'Geopotential height' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 7 ;
	}
#Geometric height
'Geometric height' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 8 ;
	}
#Absolute temperature
'Absolute temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 11 ;
	}
#Virtual temperature
'Virtual temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 12 ;
	}
#Potential temperature
'Potential temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 13 ;
	}
#Pseudo-adiabatic potential temperature
'Pseudo-adiabatic potential temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 14 ;
	}
#Maximum temperature
'Maximum temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 15 ;
	}
#Minimum temperature
'Minimum temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 16 ;
	}
#Dew point temperature
'Dew point temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 17 ;
	}
#Dew point depression
'Dew point depression' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 18 ;
	}
#Lapse rate
'Lapse rate' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 19 ;
	}
#Radar spectra(1)
'Radar spectra(1)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 21 ;
	}
#Radar spectra(2)
'Radar spectra(2)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 22 ;
	}
#Radar spectra(3)
'Radar spectra(3)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 23 ;
	}
#Temperature anomaly
'Temperature anomaly' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 25 ;
	}
#Pressure anomaly
'Pressure anomaly' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 26 ;
	}
#Geopot height anomaly
'Geopot height anomaly' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 27 ;
	}
#Wave spectra(1)
'Wave spectra(1)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra(2)
'Wave spectra(2)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra(3)
'Wave spectra(3)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 30 ;
	}
#Wind direction
'Wind direction' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 31 ;
	}
#Wind speed
'Wind speed' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 32 ;
	}
#Zonal wind (u)
'Zonal wind (u)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 33 ;
	}
#Meridional wind (v)
'Meridional wind (v)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 34 ;
	}
#Stream function
'Stream function' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 35 ;
	}
#Velocity potential
'Velocity potential' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 36 ;
	}
#Sigma coord vert vel
'Sigma coord vert vel' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 38 ;
	}
#Omega
'Omega' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical velocity
'Vertical velocity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 40 ;
	}
#Absolute vorticity
'Absolute vorticity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 41 ;
	}
#Absolute divergence
'Absolute divergence' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 42 ;
	}
#Vorticity
'Vorticity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 43 ;
	}
#Divergence
'Divergence' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 44 ;
	}
#Vertical u-comp shear
'Vertical u-comp shear' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 45 ;
	}
#Vert v-comp shear
'Vert v-comp shear' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 46 ;
	}
#Direction of current
'Direction of current' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 47 ;
	}
#Speed of current
'Speed of current' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 48 ;
	}
#U-component of current
'U-component of current' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 49 ;
	}
#V-component of current
'V-component of current' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 50 ;
	}
#Specific humidity
'Specific humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 51 ;
	}
#Relative humidity
'Relative humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 52 ;
	}
#Humidity mixing ratio
'Humidity mixing ratio' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 53 ;
	}
#Inst. precipitable water
'Inst. precipitable water' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 54 ;
	}
#Vapour pressure
'Vapour pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 55 ;
	}
#Saturation deficit
'Saturation deficit' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 56 ;
	}
#Evaporation
'Evaporation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 57 ;
	}
#Precipitation rate
'Precipitation rate' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 59 ;
	}
#Thunder probability
'Thunder probability' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation
'Total precipitation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 61 ;
	}
#Large scale precipitation
'Large scale precipitation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 62 ;
	}
#Convective precipitation
'Convective precipitation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 63 ;
	}
#Snowfall
'Snowfall' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 64 ;
	}
#Wat equiv acc snow depth
'Wat equiv acc snow depth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 65 ;
	}
#Snow depth
'Snow depth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 66 ;
	}
#Mixed layer depth
'Mixed layer depth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 67 ;
	}
#Trans thermocline depth
'Trans thermocline depth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 68 ;
	}
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 69 ;
	}
#Main thermocline anom
'Main thermocline anom' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 70 ;
	}
#Cloud cover
'Cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 71 ;
	}
#Convective cloud cover
'Convective cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 72 ;
	}
#Low cloud cover
'Low cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 73 ;
	}
#Medium cloud cover
'Medium cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 74 ;
	}
#High cloud cover
'High cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 75 ;
	}
#Cloud water
'Cloud water' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 76 ;
	}
#Best lifted index (to 500 hpa)
'Best lifted index (to 500 hpa)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 77 ;
	}
#Land sea mask
'Land sea mask' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 81 ;
	}
#Dev sea_lev from mean
'Dev sea_lev from mean' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 82 ;
	}
#Roughness length
'Roughness length' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 83 ;
	}
#Albedo
'Albedo' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 84 ;
	}
#Deep soil temperature
'Deep soil temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 85 ;
	}
#Soil moisture content
'Soil moisture content' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 86 ;
	}
#Vegetation
'Vegetation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 87 ;
	}
#Density
'Density' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 89 ;
	}
#Ice concentration
'Ice concentration' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 91 ;
	}
#Ice thickness
'Ice thickness' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 92 ;
	}
#Direction of ice drift
'Direction of ice drift' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 93 ;
	}
#Speed of ice drift
'Speed of ice drift' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 94 ;
	}
#U-comp of ice drift
'U-comp of ice drift' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 95 ;
	}
#V-comp of ice drift
'V-comp of ice drift' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 96 ;
	}
#Ice growth
'Ice growth' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 97 ;
	}
#Ice divergence
'Ice divergence' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 98 ;
	}
#Sig hgt com wave/swell
'Sig hgt com wave/swell' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 100 ;
	}
#Direction of wind wave
'Direction of wind wave' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 101 ;
	}
#Sig hght of wind waves
'Sig hght of wind waves' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period wind waves
'Mean period wind waves' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell wave
'Direction of swell wave' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 104 ;
	}
#Sig height swell waves
'Sig height swell waves' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period swell waves
'Mean period swell waves' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 106 ;
	}
#Primary wave direction
'Primary wave direction' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 107 ;
	}
#Prim wave mean period
'Prim wave mean period' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 108 ;
	}
#Second wave direction
'Second wave direction' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 109 ;
	}
#Second wave mean period
'Second wave mean period' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 110 ;
	}
#Short wave absorbed at ground
'Short wave absorbed at ground' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 111 ;
	}
#Net long wave at bottom
'Net long wave at bottom' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 112 ;
	}
#Net short-wav rad(top)
'Net short-wav rad(top)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 113 ;
	}
#Outgoing long wave at top
'Outgoing long wave at top' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 114 ;
	}
#Long-wav rad
'Long-wav rad' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 115 ;
	}
#Short wave absorbed by earth/atmosphere
'Short wave absorbed by earth/atmosphere' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 116 ;
	}
#Global radiation
'Global radiation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 117 ;
	}
#Latent heat flux from surface
'Latent heat flux from surface' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 121 ;
	}
#Sensible heat flux from surface
'Sensible heat flux from surface' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 122 ;
	}
#Bound layer dissipation
'Bound layer dissipation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 123 ;
	}
#Image
'Image' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 127 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 128 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 129 ;
	}
#10 metre u-wind component
'10 metre u-wind component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 130 ;
	}
#10 metre v-wind component
'10 metre v-wind component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 131 ;
	}
#Topography
'Topography' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 132 ;
	}
#Geometric mean surface pressure
'Geometric mean surface pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 133 ;
	}
#Ln surface pressure
'Ln surface pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'Surface pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 135 ;
	}
#M s l pressure (mesinger method)
'M s l pressure (mesinger method)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 136 ;
	}
#Mask
'Mask' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 137 ;
	}
#Maximum u-wind
'Maximum u-wind' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 138 ;
	}
#Maximum v-wind
'Maximum v-wind' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 139 ;
	}
#Convective avail. pot.energy
'Convective avail. pot.energy' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 140 ;
	}
#Convective inhib. energy
'Convective inhib. energy' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 141 ;
	}
#Convective latent heating
'Convective latent heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 142 ;
	}
#Convective moisture source
'Convective moisture source' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 143 ;
	}
#Shallow conv. moisture source
'Shallow conv. moisture source' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 144 ;
	}
#Shallow convective heating
'Shallow convective heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 145 ;
	}
#Maximum wind press. lvl
'Maximum wind press. lvl' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 146 ;
	}
#Storm motion u-component
'Storm motion u-component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 147 ;
	}
#Storm motion v-component
'Storm motion v-component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 148 ;
	}
#Mean cloud cover
'Mean cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 149 ;
	}
#Pressure at cloud base
'Pressure at cloud base' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 150 ;
	}
#Pressure at cloud top
'Pressure at cloud top' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 151 ;
	}
#Freezing level height
'Freezing level height' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 152 ;
	}
#Freezing level relative humidity
'Freezing level relative humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 153 ;
	}
#Flight levels temperature
'Flight levels temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 154 ;
	}
#Flight levels u-wind
'Flight levels u-wind' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 155 ;
	}
#Flight levels v-wind
'Flight levels v-wind' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 156 ;
	}
#Tropopause pressure
'Tropopause pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 157 ;
	}
#Tropopause temperature
'Tropopause temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 158 ;
	}
#Tropopause u-wind component
'Tropopause u-wind component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 159 ;
	}
#Tropopause v-wind component
'Tropopause v-wind component' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 160 ;
	}
#Gravity wave drag du/dt
'Gravity wave drag du/dt' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 162 ;
	}
#Gravity wave drag dv/dt
'Gravity wave drag dv/dt' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 163 ;
	}
#Gravity wave drag sfc zonal stress
'Gravity wave drag sfc zonal stress' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 164 ;
	}
#Gravity wave drag sfc meridional stress
'Gravity wave drag sfc meridional stress' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 165 ;
	}
#Divergence of specific humidity
'Divergence of specific humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 167 ;
	}
#Horiz. moisture flux conv.
'Horiz. moisture flux conv.' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 168 ;
	}
#Vert. integrated moisture flux conv.
'Vert. integrated moisture flux conv.' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 169 ;
	}
#Vertical moisture advection
'Vertical moisture advection' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 170 ;
	}
#Neg. hum. corr. moisture source
'Neg. hum. corr. moisture source' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 171 ;
	}
#Large scale latent heating
'Large scale latent heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 172 ;
	}
#Large scale moisture source
'Large scale moisture source' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 173 ;
	}
#Soil moisture availability
'Soil moisture availability' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 174 ;
	}
#Soil temperature of root zone
'Soil temperature of root zone' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 175 ;
	}
#Bare soil latent heat
'Bare soil latent heat' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 176 ;
	}
#Potential sfc evaporation
'Potential sfc evaporation' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 177 ;
	}
#Runoff
'Runoff' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 178 ;
	}
#Interception loss
'Interception loss' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 179 ;
	}
#Vapor pressure of canopy air space
'Vapor pressure of canopy air space' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 180 ;
	}
#Surface spec humidity
'Surface spec humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 181 ;
	}
#Soil wetness of surface
'Soil wetness of surface' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 182 ;
	}
#Soil wetness of root zone
'Soil wetness of root zone' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness of drainage zone
'Soil wetness of drainage zone' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 184 ;
	}
#Storage on canopy
'Storage on canopy' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 185 ;
	}
#Storage on ground
'Storage on ground' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 186 ;
	}
#Surface temperature
'Surface temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 187 ;
	}
#Surface absolute temperature
'Surface absolute temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 188 ;
	}
#Temperature of canopy air space
'Temperature of canopy air space' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 189 ;
	}
#Temperature at canopy
'Temperature at canopy' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 190 ;
	}
#Ground/surface cover temperature
'Ground/surface cover temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 191 ;
	}
#Surface zonal wind (u)
'Surface zonal wind (u)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 192 ;
	}
#Surface zonal wind stress
'Surface zonal wind stress' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 193 ;
	}
#Surface meridional wind (v)
'Surface meridional wind (v)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 194 ;
	}
#Surface meridional wind stress
'Surface meridional wind stress' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 195 ;
	}
#Surface momentum flux
'Surface momentum flux' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 196 ;
	}
#Incident short wave flux
'Incident short wave flux' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 197 ;
	}
#Time ave ground ht flx
'Time ave ground ht flx' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 198 ;
	}
#Net long wave at bottom (clear)
'Net long wave at bottom (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 200 ;
	}
#Outgoing long wave at top (clear)
'Outgoing long wave at top (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 201 ;
	}
#Short wv absrbd by earth/atmos (clear)
'Short wv absrbd by earth/atmos (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 202 ;
	}
#Short wave absorbed at ground (clear)
'Short wave absorbed at ground (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 203 ;
	}
#Long wave radiative heating
'Long wave radiative heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 205 ;
	}
#Short wave radiative heating
'Short wave radiative heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 206 ;
	}
#Downward long wave at bottom
'Downward long wave at bottom' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 207 ;
	}
#Downward long wave at bottom (clear)
'Downward long wave at bottom (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 208 ;
	}
#Downward short wave at ground
'Downward short wave at ground' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 209 ;
	}
#Downward short wave at ground (clear)
'Downward short wave at ground (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 210 ;
	}
#Upward long wave at bottom
'Upward long wave at bottom' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 211 ;
	}
#Upward short wave at ground
'Upward short wave at ground' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 212 ;
	}
#Upward short wave at ground (clear)
'Upward short wave at ground (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 213 ;
	}
#Upward short wave at top
'Upward short wave at top' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 214 ;
	}
#Upward short wave at top (clear)
'Upward short wave at top (clear)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 215 ;
	}
#Horizontal heating diffusion
'Horizontal heating diffusion' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 218 ;
	}
#Horizontal moisture diffusion
'Horizontal moisture diffusion' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 219 ;
	}
#Horizontal divergence diffusion
'Horizontal divergence diffusion' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 220 ;
	}
#Horizontal vorticity diffusion
'Horizontal vorticity diffusion' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 221 ;
	}
#Vertical diff. moisture source
'Vertical diff. moisture source' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 222 ;
	}
#Vertical diffusion du/dt
'Vertical diffusion du/dt' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion dv/dt
'Vertical diffusion dv/dt' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 224 ;
	}
#Vertical diffusion heating
'Vertical diffusion heating' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 225 ;
	}
#Surface relative humidity
'Surface relative humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 226 ;
	}
#Vertical dist total cloud cover
'Vertical dist total cloud cover' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 227 ;
	}
#Time mean surface zonal wind (u)
'Time mean surface zonal wind (u)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 230 ;
	}
#Time mean surface meridional wind (v)
'Time mean surface meridional wind (v)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 231 ;
	}
#Time mean surface absolute temperature
'Time mean surface absolute temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 232 ;
	}
#Time mean surface relative humidity
'Time mean surface relative humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 233 ;
	}
#Time mean absolute temperature
'Time mean absolute temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 234 ;
	}
#Time mean deep soil temperature
'Time mean deep soil temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 235 ;
	}
#Time mean derived omega
'Time mean derived omega' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 236 ;
	}
#Time mean divergence
'Time mean divergence' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 237 ;
	}
#Time mean geopotential height
'Time mean geopotential height' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 238 ;
	}
#Time mean log surface pressure
'Time mean log surface pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 239 ;
	}
#Time mean mask
'Time mean mask' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 240 ;
	}
#Time mean meridional wind (v)
'Time mean meridional wind (v)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 241 ;
	}
#Time mean omega
'Time mean omega' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 242 ;
	}
#Time mean potential temperature
'Time mean potential temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 243 ;
	}
#Time mean precip. water
'Time mean precip. water' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 244 ;
	}
#Time mean relative humidity
'Time mean relative humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 245 ;
	}
#Time mean sea level pressure
'Time mean sea level pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 246 ;
	}
#Time mean sigmadot
'Time mean sigmadot' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 247 ;
	}
#Time mean specific humidity
'Time mean specific humidity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 248 ;
	}
#Time mean stream function
'Time mean stream function' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 249 ;
	}
#Time mean surface pressure
'Time mean surface pressure' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 250 ;
	}
#Time mean surface temperature
'Time mean surface temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 251 ;
	}
#Time mean velocity potential
'Time mean velocity potential' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 252 ;
	}
#Time mean virtual temperature
'Time mean virtual temperature' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 253 ;
	}
#Time mean vorticity
'Time mean vorticity' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 254 ;
	}
#Time mean zonal wind (u)
'Time mean zonal wind (u)' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 255 ;
}
