# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.33, Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for simulated (synthetic) satellite data

include "grib2/template.4.32.def"
include "grib2/template.4.eps.def"

alias instrument = instrumentType;
alias ident = satelliteNumber;

