# (C) Copyright 2005- ECMWF.
# Predefined grid 21

constant Ni = 91;
constant Nj = 46;

constant longitudeOfFirstGridPoint = -180000;
constant longitudeOfLastGridPoint = 0;

constant latitudeOfFirstGridPoint = -90000;
constant latitudeOfLastGridPoint = 0;

constant iDirectionIncrement = 2000;
constant jDirectionIncrement = 2000;

constant numberOfDataPoints=4186;
constant numberOfValues=4096 ;

