# (C) Copyright 2005- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# 
# In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
# virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
#

# TEMPLATE 4.80, Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for optical properties of aerosol with source/sink

include "grib2/template.4.parameter_aerosol_optical_source.def";
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def";
