# (C) Copyright 2005- ECMWF.

signed[3] latitudeOfSouthernPole : edition_specific;
meta  geography.latitudeOfSouthernPoleInDegrees   scale(latitudeOfSouthernPole ,oneConstant,grib1divider,truncateDegrees) : dump;

signed[3] longitudeOfSouthernPole : edition_specific ;
meta  geography.longitudeOfSouthernPoleInDegrees   scale(longitudeOfSouthernPole ,oneConstant,grib1divider,truncateDegrees) : dump;

ibmfloat geography.angleOfRotationInDegrees : dump;

alias angleOfRotation =angleOfRotationInDegrees;
alias isRotatedGrid = one;
