# Seasonal forecast monthly mean data for lagged systems

unsigned[2] systemNumber : dump;
unsigned[2] methodNumber : dump;

alias local.systemNumber=systemNumber;
alias local.methodNumber=methodNumber;

unsigned[4] indexingDate: dump; # MARS archiving date (YYYYMMDD)
unsigned[2] indexingTime: dump; # MARS archiving time (HHMM)
alias mars.date = indexingDate;
alias mars.time = indexingTime;

pad padding_loc12_1(50);
