# (C) Copyright 2005- ECMWF.

# For grib2 to grib1 conversion
constant dataRepresentationType = 90;

# TEMPLATE 4.31, Satellite Product
codetable[1] parameterCategory ('4.1.[discipline:l].table',masterDir,localDir)  : dump;
codetable[1] parameterNumber ('4.2.[discipline:l].[parameterCategory:l].table',masterDir,localDir)  : dump;
meta parameterUnits codetable_units(parameterNumber) : dump;
meta parameterName  codetable_title(parameterNumber) : dump;

codetable[1] typeOfGeneratingProcess ('4.3.table',masterDir,localDir) : dump;

#  Observation generating process identifier (defined by originating centre)
unsigned[1] observationGeneratingProcessIdentifier  : dump;
alias generatingProcessIdentifier=observationGeneratingProcessIdentifier;

unsigned[1] NB  : dump;
alias numberOfContributingSpectralBands=NB;

listOfContributingSpectralBands list(numberOfContributingSpectralBands){
      unsigned[2] satelliteSeries : dump;
      unsigned[2] satelliteNumber : dump;
      unsigned[2] instrumentType : dump;
      unsigned[1] scaleFactorOfCentralWaveNumber = missing() : dump,can_be_missing ;
      unsigned[4] scaledValueOfCentralWaveNumber = missing() : dump,can_be_missing ;
}
