# (C) Copyright 2005- ECMWF.

# TEMPLATE 7.6, Grid point data - simple packing with preprocessing
# Octets 6-nn : Binary data values - binary string, with each (scaled)

meta codedValues data_g2simple_packing_with_preprocessing(
        section7Length,
        offsetBeforeData,
        offsetSection7,
        unitsFactor,
        unitsBias,
        changingPrecision,
        numberOfValues,
        bitsPerValue,
        referenceValue,
        binaryScaleFactor,
        decimalScaleFactor,
        optimizeScaleFactor,
        typeOfPreProcessing,
        preProcessingParameter
  ): read_only;

meta values data_apply_bitmap(codedValues,
                              bitmap,
                              missingValue,
                              binaryScaleFactor,
                              numberOfDataPoints,
                              numberOfValues) : dump;

alias data.packedValues = codedValues;

template statistics "common/statistics_grid.def";
