# (C) Copyright 2005- ECMWF.

# For grib2 to grib1 conversion
constant dataRepresentationType = 90;

# TEMPLATE 4.32, Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for simulated (synthetic) satellite data

include "grib2/template.4.parameter.def"
include "grib2/template.4.point_in_time.def";

# Required for interpolation and MARS. The level type is used to decide whether to apply the Land Sea Mask
constant typeOfLevel="surface";
constant levelType="surface";
constant level=0;

unsigned[1] NB  : dump;
alias numberOfContributingSpectralBands=NB;

listOfContributingSpectralBands list(numberOfContributingSpectralBands){
      unsigned[2] satelliteSeries : dump;
      unsigned[2] satelliteNumber : dump;
      unsigned[2] instrumentType : dump;
      unsigned[1] scaleFactorOfCentralWaveNumber = missing() : dump,can_be_missing ;
      unsigned[4] scaledValueOfCentralWaveNumber = missing() : dump,can_be_missing ;
}
