# (C) Copyright 2005- ECMWF.

# TEMPLATE 4.51, Categorical forecasts at a horizontal level or in a horizontal layer at a point in time

include "grib2/template.4.parameter.def"
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def"
include "grib2/template.4.categorical.def"
