# Automatically generated by ./create_def.pl, do not edit
#Sea ice area fraction
'sea_ice_area_fraction' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 31 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 129 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 129 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 130 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 130 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 131 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 131 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 132 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 132 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 133 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 133 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 162 ;
	 indicatorOfParameter = 52 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 134 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 135 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 135 ;
	}
#Total column water vapour
'lwe_thickness_of_atmosphere_mass_content_of_water_vapor' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 137 ;
	}
#Total column water vapour
'lwe_thickness_of_atmosphere_mass_content_of_water_vapor' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 137 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 138 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 138 ;
	}
#Soil temperature level 1
'surface_temperature' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'surface_temperature' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'surface_temperature' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 139 ;
	}
#Soil temperature level 1
'surface_temperature' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 139 ;
	}
#Soil wetness level 1
'lwe_thickness_of_soil_moisture_content' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 140 ;
	}
#Soil wetness level 1
'lwe_thickness_of_soil_moisture_content' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 140 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 141 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 141 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 141 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 142 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 142 ;
	}
#Large-scale precipitation
'lwe_thickness_of_stratiform_precipitation_amount' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 142 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 143 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 143 ;
	}
#Convective precipitation
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 143 ;
	}
#Snowfall
'lwe_thickness_of_snowfall_amount' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 144 ;
	}
#Snowfall
'lwe_thickness_of_snowfall_amount' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 144 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 145 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 145 ;
	}
#Surface sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 146 ;
	}
#Surface sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 146 ;
	}
#Surface latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 147 ;
	}
#Surface latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 147 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 151 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 151 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 155 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 155 ;
	}
#Geopotential Height
'geopotential_height' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 156 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 157 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 157 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 157 ;
	}
#Tendency of surface pressure
'tendency_of_surface_air_pressure' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 158 ;
	}
#Tendency of surface pressure
'tendency_of_surface_air_pressure' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 158 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 164 ;
	}
#Total cloud cover
'cloud_area_fraction' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 164 ;
	}
#Surface solar radiation downwards
'surface_downwelling_shortwave_flux_in_air' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 169 ;
	}
#Surface solar radiation downwards
'surface_downwelling_shortwave_flux_in_air' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 169 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 171 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 175 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 172 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 172 ;
	}
#Surface roughness
'surface_roughness_length' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 173 ;
	}
#Surface roughness
'surface_roughness_length' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 173 ;
	}
#Albedo
'surface_albedo' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 174 ;
	}
#Albedo
'surface_albedo' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 174 ;
	}
#Albedo
'surface_albedo' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 174 ;
	}
#Surface net solar radiation
'surface_net_downward_shortwave_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'surface_net_downward_shortwave_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'surface_net_downward_shortwave_flux' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net solar radiation
'surface_net_downward_shortwave_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 176 ;
	}
#Surface net thermal radiation
'surface_net_upward_longwave_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'surface_net_upward_longwave_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'surface_net_upward_longwave_flux' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 177 ;
	}
#Surface net thermal radiation
'surface_net_upward_longwave_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 177 ;
	}
#Top net solar radiation
'toa_net_upward_shortwave_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 178 ;
	}
#Top net solar radiation
'toa_net_upward_shortwave_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 178 ;
	}
#Top net solar radiation
'toa_net_upward_shortwave_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 178 ;
	}
#Top net thermal radiation
'toa_outgoing_longwave_flux' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 179 ;
	}
#Top net thermal radiation
'toa_outgoing_longwave_flux' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 179 ;
	}
#Top net thermal radiation
'toa_outgoing_longwave_flux' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 179 ;
	}
#Eastward turbulent surface stress
'surface_downward_eastward_stress' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 180 ;
	}
#Eastward turbulent surface stress
'surface_downward_eastward_stress' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 180 ;
	}
#Eastward turbulent surface stress
'surface_downward_eastward_stress' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 180 ;
	}
#Northward turbulent surface stress
'surface_downward_northward_stress' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 181 ;
	}
#Northward turbulent surface stress
'surface_downward_northward_stress' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 181 ;
	}
#Northward turbulent surface stress
'surface_downward_northward_stress' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 181 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 180 ;
	 indicatorOfParameter = 182 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 190 ;
	 indicatorOfParameter = 182 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 185 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 185 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 170 ;
	 indicatorOfParameter = 185 ;
	}
#Ozone mass mixing ratio
'mass_fraction_of_ozone_in_air' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 203 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 206 ;
	}
#Surface net solar radiation, clear sky
'surface_net_downward_shortwave_flux_assuming_clear_sky' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 210 ;
	}
#Surface net thermal radiation, clear sky
'surface_net_downward_longwave_flux_assuming_clear_sky' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 211 ;
	}
#Temperature of snow layer
'temperature_in_surface_snow' = {
	 table2Version = 128 ;
	 indicatorOfParameter = 238 ;
	}
#Temperature of snow layer
'temperature_in_surface_snow' = {
	 table2Version = 160 ;
	 indicatorOfParameter = 238 ;
	}
#Sea ice snow thickness
'surface_snow_thickness' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 97 ;
	}
#Particulate matter d < 1 um
'mass_concentration_of_pm1_ambient_aerosol_particles_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 72 ;
	}
#Particulate matter d < 2.5 um
'mass_concentration_of_pm2p5_ambient_aerosol_particles_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 73 ;
	}
#Particulate matter d < 10 um
'mass_concentration_of_pm10_ambient_aerosol_particles_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 74 ;
	}
#Hydrogen peroxide
'mass_fraction_of_hydrogen_peroxide_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 3 ;
	}
#Methane (chemistry)
'mass_fraction_of_methane_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 4 ;
	}
#Nitric acid
'mass_fraction_of_nitric_acid_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 6 ;
	}
#Ethene
'mass_fraction_of_ethene_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 10 ;
	}
#Peroxyacetyl nitrate
'mass_fraction_of_peroxyacetyl_nitrate_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 13 ;
	}
#Isoprene
'mass_fraction_of_isoprene_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 16 ;
	}
#Dimethyl sulfide
'mass_fraction_of_dimethyl_sulfide_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 18 ;
	}
#Ammonia
'mass_fraction_of_ammonia_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 19 ;
	}
#Nitrogen monoxide
'mass_fraction_of_nitrogen_monoxide_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 27 ;
	}
#Hydroxyl radical
'mass_fraction_of_hydroxyl_radical_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 30 ;
	}
#Nitrate radical
'mass_fraction_of_nitrate_radical_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 32 ;
	}
#Dinitrogen pentoxide
'mass_fraction_of_dinitrogen_pentoxide_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 33 ;
	}
#Methanol
'mass_fraction_of_methanol_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 42 ;
	}
#Formic acid
'mass_fraction_of_formic_acid_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 43 ;
	}
#Ethane
'mass_fraction_of_ethane_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 45 ;
	}
#Ethanol
'mass_fraction_of_ethanol_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 46 ;
	}
#Propane
'mass_fraction_of_propane_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 47 ;
	}
#Propene
'mass_fraction_of_propene_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 48 ;
	}
#Terpenes
'mass_fraction_of_terpenes_in_air' = {
	 table2Version = 217 ;
	 indicatorOfParameter = 49 ;
	}
#Total column hydrogen peroxide
'atmosphere_mass_content_of_hydrogen_peroxide' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 3 ;
	}
#Total column methane
'atmosphere_mass_content_of_methane' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 4 ;
	}
#Total column nitric acid
'atmosphere_mass_content_of_nitric_acid' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 6 ;
	}
#Total column ethene
'atmosphere_mass_content_of_ethene' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 10 ;
	}
#Total column  peroxyacetyl nitrate
'atmosphere_mass_content_of_peroxyacetyl_nitrate' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 13 ;
	}
#Total column  isoprene
'atmosphere_mass_content_of_isoprene' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 16 ;
	}
#Total column dimethyl sulfide
'atmosphere_mass_content_of_dimethyl_sulfide' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 18 ;
	}
#Total column ammonia
'atmosphere_mass_content_of_ammonia' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 19 ;
	}
#Total column  sulfate
'atmosphere_mass_content_of_sulfate' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 20 ;
	}
#Total column nitrogen monoxide
'atmosphere_mass_content_of_nitrogen_monoxide' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 27 ;
	}
#Total column hydroxyl radical
'atmosphere_mass_content_of_hydroxyl_radical' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 30 ;
	}
#Total column nitrate radical
'atmosphere_mass_content_of_nitrate_radical' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 32 ;
	}
#Total column dinitrogen pentoxide
'atmosphere_mass_content_of_dinitrogen_pentoxide' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 33 ;
	}
#Total column methanol
'atmosphere_mass_content_of_methanol' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 42 ;
	}
#Total column formic acid
'atmosphere_mass_content_of_formic_acid' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 43 ;
	}
#Total column  ethane
'atmosphere_mass_content_of_ethane' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 45 ;
	}
#Total column ethanol
'atmosphere_mass_content_of_ethanol' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 46 ;
	}
#Total column propane
'atmosphere_mass_content_of_propane' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 47 ;
	}
#Total column propene
'atmosphere_mass_content_of_propene' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 48 ;
	}
#Total column terpenes
'atmosphere_mass_content_of_terpenes' = {
	 table2Version = 218 ;
	 indicatorOfParameter = 49 ;
	}
#Sea water potential temperature
'sea_water_potential_temperature' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 129 ;
	}
#Sea water practical salinity
'sea_water_practical_salinity' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 130 ;
	}
#Eastward sea water velocity
'eastward_sea_water_velocity' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 131 ;
	}
#Northward sea water velocity
'northward_sea_water_velocity' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 132 ;
	}
#Upward sea water velocity
'upward_sea_water_velocity' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 133 ;
	}
#Sea water sigma theta
'sea_water_sigma_theta' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 138 ;
	}
#Sea surface height
'sea_surface_height_above_geoid' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 145 ;
	}
#Ocean barotropic stream function
'ocean_barotropic_streamfunction' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 147 ;
	}
#Surface downward eastward stress
'surface_downward_eastward_stress' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 153 ;
	}
#Surface downward northward stress
'surface_downward_northward_stress' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 154 ;
	}
#Depth of 20C isotherm
'depth_of_isosurface_of_sea_water_potential_temperature' = {
	 table2Version = 151 ;
	 indicatorOfParameter = 163 ;
	}
#Sea-ice thickness
'sea_ice_thickness' = {
	 table2Version = 174 ;
	 indicatorOfParameter = 98 ;
	}
#Carbon Dioxide
'mass_fraction_of_carbon_dioxide_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 61 ;
	}
#Methane
'mass_fraction_of_methane_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 62 ;
	}
#Nitrous oxide
'mass_fraction_of_nitrous_oxide_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 63 ;
	}
#Total column Nitrous oxide
'atmosphere_mass_content_of_nitrous_oxide' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 66 ;
	}
#Nitrogen dioxide
'mass_fraction_of_nitrogen_dioxide_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 121 ;
	}
#Sulphur dioxide
'mass_fraction_of_sulfur_dioxide_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 122 ;
	}
#Carbon monoxide
'mass_fraction_of_carbon_monoxide_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 123 ;
	}
#Formaldehyde
'mass_fraction_of_formaldehyde_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 124 ;
	}
#Total column Nitrogen dioxide
'atmosphere_mass_content_of_nitrogen_dioxide' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 125 ;
	}
#Total column Sulphur dioxide
'atmosphere_mass_content_of_sulfur_dioxide' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 126 ;
	}
#Total column Carbon monoxide
'atmosphere_mass_content_of_carbon_monoxide' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 127 ;
	}
#Total column Formaldehyde
'atmosphere_mass_content_of_formaldehyde' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 128 ;
	}
#Radon
'mass_fraction_of_radon_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 181 ;
	}
#Total column Radon
'atmosphere_mass_content_of_radon' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 183 ;
	}
#GEMS Ozone
'mass_fraction_of_ozone_in_air' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 203 ;
	}
#GEMS Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 206 ;
}
