# (C) Copyright 2005- ECMWF.

# TEMPLATE 7.1, Matrix values at grid point -simple packing
# Octets 6-nn : Binary data values - binary string, with each
# (scaled)
# ????          data_values__binary_string_with_each

meta codedValues data_g2simple_packing(
        section7Length,
        offsetBeforeData,
        offsetSection7,
        unitsFactor,
        unitsBias,
        changingPrecision,
        numberOfValues,
        bitsPerValue,
        referenceValue,
        binaryScaleFactor,
        decimalScaleFactor,
        optimizeScaleFactor
  ): read_only;

meta values data_apply_bitmap(codedValues,
                              bitmap,
                              missingValue,
                              binaryScaleFactor,
                              numberOfDataPoints,
                              numberOfValues) : dump;

meta packingError simple_packing_error(bitsPerValue,binaryScaleFactor,decimalScaleFactor,referenceValue,ieee) : no_copy;
meta unpackedError simple_packing_error(zero,binaryScaleFactor,decimalScaleFactor,referenceValue,ieee) : no_copy;

alias data.packedValues = codedValues;

template statistics "common/statistics_grid.def";
