#Surface net solar radiation, clear sky
'ssrc' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 210 ;
}
#Surface net thermal radiation, clear sky
'strc' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 211 ;
}
#Eastward sea water velocity
'ocu' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 131 ;
}
#Northward sea water velocity
'ocv' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 132 ;
}
#Sea-ice thickness
'sithick' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 98 ;
}
#Sea surface height
'zos' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 145 ;
}
#100 metre U wind component
'100u' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 246 ;
}
#100 metre V wind component
'100v' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 247 ;
}
#100 metre wind speed
'100si' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 249 ;
}
#0 degrees C isothermal level (atm)
'deg0l' = {
 discipline = 192 ;
 parameterCategory = 228 ;
 parameterNumber = 24 ;
}
#Depth of 20C isotherm
't20d' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 163 ;
}
#Average salinity in the upper 300m
'sav300' = {
 discipline = 192 ;
 parameterCategory = 151 ;
 parameterNumber = 175 ;
}
#Total precipitation of at least 1 mm
'tpg1' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 60 ;
}
#Total precipitation of at least 5 mm
'tpg5' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 61 ;
}
#Total precipitation of at least 40 mm
'tpg40' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 82 ;
}
#Total precipitation of at least 60 mm
'tpg60' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 83 ;
}
#Total precipitation of at least 80 mm
'tpg80' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 84 ;
}
#Total precipitation of at least 150 mm
'tpg150' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 86 ;
}
#Total precipitation of at least 200 mm
'tpg200' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 87 ;
}
#Total precipitation of at least 300 mm
'tpg300' = {
 discipline = 192 ;
 parameterCategory = 131 ;
 parameterNumber = 88 ;
}
#Total column cloud liquid water
'tclw' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 78 ;
}
#Total column cloud ice water
'tciw' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 79 ;
}
#Top net solar radiation
'tsr' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 178 ;
}
#Temperature of snow layer
'tsn' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 238 ;
}
#Sea-ice cover
'ci' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 31 ;
}
#Snow density
'rsn' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 33 ;
}
#Sea surface temperature
'sst' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 34 ;
}
#Surface solar radiation downwards
'ssrd' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 169 ;
}
#Surface thermal radiation downwards
'strd' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 175 ;
}
#Eastward turbulent surface stress
'ewss' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 180 ;
}
#Northward turbulent surface stress
'nsss' = {
 discipline = 192 ;
 parameterCategory = 128 ;
 parameterNumber = 181 ;
}
#Surface runoff
'sro' = {
 discipline = 192 ;
 parameterCategory = 174 ;
 parameterNumber = 8 ;
}
