# file generated by get_86_paramdef_for_grib_api.pl at 2014-11-14 10:59:45 EET host gogol.fmi.fi
'P-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 1 ;
}
'Z-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 2 ;
}
'HL-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 3 ;
}
'T-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 4 ;
}
'TP-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 8 ;
}
'TPW-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 9 ;
}
'TD-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 10 ;
}
'Q-KGKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 12 ;
}
'RH-PRCNT' = {
	table2Version = 203 ;
	indicatorOfParameter = 13 ;
}
'CLDSYM-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 15 ;
}
'FRNTSYM-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 18 ;
}
'FOGSYM-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 19 ;
}
'DD-D' = {
	table2Version = 203 ;
	indicatorOfParameter = 20 ;
}
'FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 21 ;
}
'DF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 22 ;
}
'U-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 23 ;
}
'V-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 24 ;
}
'FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 27 ;
}
'HM20C-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 28 ;
}
'ABSVO-HZ-5' = {
	table2Version = 203 ;
	indicatorOfParameter = 31 ;
}
'AQI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 38 ;
}
'FF10-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 39 ;
}
'VV-PAS' = {
	table2Version = 203 ;
	indicatorOfParameter = 40 ;
}
'VV-MMS' = {
	table2Version = 203 ;
	indicatorOfParameter = 43 ;
}
'VV-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 44 ;
}
'PRCWAT-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 47 ;
}
'RR-MM10' = {
	table2Version = 203 ;
	indicatorOfParameter = 50 ;
}
'SD-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 51 ;
}
'HSADE1-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 52 ;
}
'HSADE2-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 53 ;
}
'RR-6-MM' = {
	table2Version = 203 ;
	indicatorOfParameter = 54 ;
}
'RR-12-MM' = {
	table2Version = 203 ;
	indicatorOfParameter = 55 ;
}
'RR-1-MM' = {
	table2Version = 203 ;
	indicatorOfParameter = 56 ;
}
'RR-2-MM' = {
	table2Version = 203 ;
	indicatorOfParameter = 57 ;
}
'RR-3-MM' = {
	table2Version = 203 ;
	indicatorOfParameter = 58 ;
}
'PRECFORM-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 59 ;
}
'SMOGI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 60 ;
}
'RRL-MM10' = {
	table2Version = 203 ;
	indicatorOfParameter = 62 ;
}
'RRC-MM10' = {
	table2Version = 203 ;
	indicatorOfParameter = 63 ;
}
'SNACC-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 68 ;
}
'RNETLW-WM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 69 ;
}
'H0C-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 70 ;
}
'RRR-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 71 ;
}
'RRRC-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 72 ;
}
'RRRL-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 73 ;
}
'LNSP-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 74 ;
}
'TG-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 75 ;
}
'LSSN-M100' = {
	table2Version = 203 ;
	indicatorOfParameter = 77 ;
}
'CLDWAT-KGKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 78 ;
}
'N-PRCNT' = {
	table2Version = 203 ;
	indicatorOfParameter = 79 ;
}
'KINDEX-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 80 ;
}
'ALBEDO' = {
	table2Version = 203 ;
	indicatorOfParameter = 89 ;
}
'HESSAA-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 91 ;
}
'RADLW-WM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 95 ;
}
'RADGLO-WM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 96 ;
}
'LC-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 99 ;
}
'IC-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 100 ;
}
'RHO-KGM3' = {
	table2Version = 203 ;
	indicatorOfParameter = 101 ;
}
'SSICING-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 102 ;
}
'ICING-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 103 ;
}
'CLDICE-KGKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 104 ;
}
'CLDCND-KGKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 105 ;
}
'SNL-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 106 ;
}
'SNC-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 107 ;
}
'SNRL-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 108 ;
}
'SNRC-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 109 ;
}
'SNR-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 110 ;
}
'T-C1-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 111 ;
}
'T-C2-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 112 ;
}
'T-C3-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 113 ;
}
'T-C4-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 114 ;
}
'T-C5-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 115 ;
}
'T-C6-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 116 ;
}
'Z-C1-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 117 ;
}
'Z-C2-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 118 ;
}
'Z-C3-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 119 ;
}
'Z-C4-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 120 ;
}
'Z-C5-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 121 ;
}
'Z-C6-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 122 ;
}
'RTOPLW-WM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 126 ;
}
'RNETSW-WM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 128 ;
}
'TPE-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 129 ;
}
'ABSH-KGM3' = {
	table2Version = 203 ;
	indicatorOfParameter = 130 ;
}
'PROB-T-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 131 ;
}
'PROB-T-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 132 ;
}
'PROB-T-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 133 ;
}
'PROB-T-4' = {
	table2Version = 203 ;
	indicatorOfParameter = 134 ;
}
'PROB-RR-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 141 ;
}
'PROB-RR-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 142 ;
}
'PROB-RR-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 143 ;
}
'PROB-RR-4' = {
	table2Version = 203 ;
	indicatorOfParameter = 144 ;
}
'WSH-KT' = {
	table2Version = 203 ;
	indicatorOfParameter = 145 ;
}
'WSH-1-KT' = {
	table2Version = 203 ;
	indicatorOfParameter = 146 ;
}
'HLCY-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 147 ;
}
'HLCY-1-M2S2' = {
	table2Version = 203 ;
	indicatorOfParameter = 148 ;
}
'FF1500-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 149 ;
}
'TPE3-C' = {
	table2Version = 203 ;
	indicatorOfParameter = 150 ;
}
'PROB-W-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 151 ;
}
'PROB-W-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 152 ;
}
'PROB-WG-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 153 ;
}
'PROB-WG-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 154 ;
}
'PROB-WG-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 155 ;
}
'EFI-WS' = {
	table2Version = 203 ;
	indicatorOfParameter = 156 ;
}
'EFI-T' = {
	table2Version = 203 ;
	indicatorOfParameter = 157 ;
}
'EFI-WG' = {
	table2Version = 203 ;
	indicatorOfParameter = 158 ;
}
'EFI-RR' = {
	table2Version = 203 ;
	indicatorOfParameter = 159 ;
}
'PROBSN-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 161 ;
}
'MOL-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 163 ;
}
'SRMOM-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 164 ;
}
'RRI-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 165 ;
}
'RSI-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 166 ;
}
'MIXHGT-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 167 ;
}
'SI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 168 ;
}
'LI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 169 ;
}
'CTI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 170 ;
}
'VTI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 171 ;
}
'TTI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 172 ;
}
'F0-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 173 ;
}
'F10-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 174 ;
}
'F25-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 175 ;
}
'F50-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 176 ;
}
'F75-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 177 ;
}
'F90-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 178 ;
}
'F100-T-K' = {
	table2Version = 203 ;
	indicatorOfParameter = 179 ;
}
'LCL-MU-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 180 ;
}
'LFC-MU-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 181 ;
}
'EL-MU-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 182 ;
}
'SR-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 183 ;
}
'LCL-MU-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 184 ;
}
'LFC-MU-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 185 ;
}
'SM-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 186 ;
}
'F0-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 187 ;
}
'F10-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 188 ;
}
'F25-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 189 ;
}
'F50-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 190 ;
}
'F75-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 191 ;
}
'F90-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 192 ;
}
'F100-RR-6' = {
	table2Version = 203 ;
	indicatorOfParameter = 193 ;
}
'EL-MU-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 194 ;
}
'CAPE-MU-JKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 195 ;
}
'UVIMAX-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 196 ;
}
'UVI-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 197 ;
}
'O3ANOM-PRCNT' = {
	table2Version = 203 ;
	indicatorOfParameter = 198 ;
}
'CIN-MU-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 199 ;
}
'CANW-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 200 ;
}
'FLLAT-JM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 201 ;
}
'FLSEN-JM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 202 ;
}
'FLMOM-PA' = {
	table2Version = 203 ;
	indicatorOfParameter = 203 ;
}
'CAPE-0-3-MU' = {
	table2Version = 203 ;
	indicatorOfParameter = 204 ;
}
'CAPE1040-MU' = {
	table2Version = 203 ;
	indicatorOfParameter = 205 ;
}
'ILSAA1-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 206 ;
}
'SOILTY-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 207 ;
}
'TKEN-JKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 208 ;
}
'UFLMOM-NM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 209 ;
}
'VFLMOM-NM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 210 ;
}
'VEGET-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 211 ;
}
'GRR-MMH' = {
	table2Version = 203 ;
	indicatorOfParameter = 212 ;
}
'RRRS-KGM2' = {
	table2Version = 203 ;
	indicatorOfParameter = 213 ;
}
'F0-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 214 ;
}
'F10-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 215 ;
}
'F25-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 216 ;
}
'F50-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 217 ;
}
'F75-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 218 ;
}
'F90-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 219 ;
}
'F100-N-0TO1' = {
	table2Version = 203 ;
	indicatorOfParameter = 220 ;
}
'F0-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 221 ;
}
'F10-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 222 ;
}
'F25-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 223 ;
}
'F50-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 224 ;
}
'F75-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 225 ;
}
'F90-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 226 ;
}
'F100-FFG-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 227 ;
}
'F0-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 228 ;
}
'F10-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 229 ;
}
'F25-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 230 ;
}
'F50-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 231 ;
}
'F75-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 232 ;
}
'F90-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 233 ;
}
'F100-FF-MS' = {
	table2Version = 203 ;
	indicatorOfParameter = 234 ;
}
'LCL-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 235 ;
}
'LFC-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 236 ;
}
'EL-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 237 ;
}
'LCL-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 238 ;
}
'LFC-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 239 ;
}
'EL-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 240 ;
}
'CAPE-JKG' = {
	table2Version = 203 ;
	indicatorOfParameter = 241 ;
}
'CAPE-500' = {
	table2Version = 203 ;
	indicatorOfParameter = 242 ;
}
'CAPE1040' = {
	table2Version = 203 ;
	indicatorOfParameter = 243 ;
}
'CIN-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 244 ;
}
'LCL-500-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 245 ;
}
'LFC-500-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 246 ;
}
'EL-500-HPA' = {
	table2Version = 203 ;
	indicatorOfParameter = 247 ;
}
'LCL-500-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 248 ;
}
'LFC-500-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 249 ;
}
'EL-500-M' = {
	table2Version = 203 ;
	indicatorOfParameter = 250 ;
}
'CAPE-0-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 251 ;
}
'CAPE-0-3-500' = {
	table2Version = 203 ;
	indicatorOfParameter = 252 ;
}
'CAPE1040-500' = {
	table2Version = 203 ;
	indicatorOfParameter = 253 ;
}
'CIN-500-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 254 ;
}
'PRECFORM2-N' = {
	table2Version = 203 ;
	indicatorOfParameter = 255 ;
}
'TSEA-C' = {
	table2Version = 205 ;
	indicatorOfParameter = 1 ;
}
'ICNCT-PRCNT' = {
	table2Version = 205 ;
	indicatorOfParameter = 2 ;
}
'ITHK-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 3 ;
}
'IMINTHK-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 4 ;
}
'IMAXTHK-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 5 ;
}
'IRIDGE-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 6 ;
}
'IVELU-MS' = {
	table2Version = 205 ;
	indicatorOfParameter = 7 ;
}
'IVELV-MS' = {
	table2Version = 205 ;
	indicatorOfParameter = 8 ;
}
'IMEANTHK-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 9 ;
}
'IRIDGC-PRCNT' = {
	table2Version = 205 ;
	indicatorOfParameter = 10 ;
}
'IRAFTTHK-CM' = {
	table2Version = 205 ;
	indicatorOfParameter = 11 ;
}
'IRCNCT-PRCNT' = {
	table2Version = 205 ;
	indicatorOfParameter = 12 ;
}
'IDD-D' = {
	table2Version = 205 ;
	indicatorOfParameter = 13 ;
}
'IFF-MS' = {
	table2Version = 205 ;
	indicatorOfParameter = 14 ;
}
'P-PA' = {
	table2Version = 253 ;
	indicatorOfParameter = 1 ;
}
'P-PA' = {
	table2Version = 253 ;
	indicatorOfParameter = 2 ;
}
'Z-M2S2' = {
	table2Version = 253 ;
	indicatorOfParameter = 6 ;
}
'HL-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 8 ;
}
'T-K' = {
	table2Version = 253 ;
	indicatorOfParameter = 11 ;
}
'TP-K' = {
	table2Version = 253 ;
	indicatorOfParameter = 13 ;
}
'TMAX-C' = {
	table2Version = 253 ;
	indicatorOfParameter = 15 ;
}
'TMIN-C' = {
	table2Version = 253 ;
	indicatorOfParameter = 16 ;
}
'TD-K' = {
	table2Version = 253 ;
	indicatorOfParameter = 17 ;
}
'VV-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 20 ;
}
'U-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 33 ;
}
'V-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 34 ;
}
'VV-PAS' = {
	table2Version = 253 ;
	indicatorOfParameter = 39 ;
}
'VV-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 40 ;
}
'ABSVO-HZ' = {
	table2Version = 253 ;
	indicatorOfParameter = 41 ;
}
'Q-KGKG' = {
	table2Version = 253 ;
	indicatorOfParameter = 51 ;
}
'RH-PRCNT' = {
	table2Version = 253 ;
	indicatorOfParameter = 52 ;
}
'PRCWAT-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 54 ;
}
'EVAP-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 57 ;
}
'CLDICE-KGKG' = {
	table2Version = 253 ;
	indicatorOfParameter = 58 ;
}
'RR-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 61 ;
}
'SD-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 66 ;
}
'MIXHGT-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 67 ;
}
'N-0TO1' = {
	table2Version = 253 ;
	indicatorOfParameter = 71 ;
}
'NL-PRCNT' = {
	table2Version = 253 ;
	indicatorOfParameter = 73 ;
}
'NM-PRCNT' = {
	table2Version = 253 ;
	indicatorOfParameter = 74 ;
}
'NH-PRCNT' = {
	table2Version = 253 ;
	indicatorOfParameter = 75 ;
}
'CLDWAT-KGKG' = {
	table2Version = 253 ;
	indicatorOfParameter = 76 ;
}
'LC-0TO1' = {
	table2Version = 253 ;
	indicatorOfParameter = 81 ;
}
'SR-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 83 ;
}
'ALBEDO' = {
	table2Version = 253 ;
	indicatorOfParameter = 84 ;
}
'SM-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 86 ;
}
'IC-0TO1' = {
	table2Version = 253 ;
	indicatorOfParameter = 91 ;
}
'DW-D' = {
	table2Version = 253 ;
	indicatorOfParameter = 101 ;
}
'HWS-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 102 ;
}
'PWS-S' = {
	table2Version = 253 ;
	indicatorOfParameter = 103 ;
}
'RNETSWA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 111 ;
}
'RNETLWA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 112 ;
}
'RTOPSW-WM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'RTOPSWA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'RTOPLW-WM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'RTOPLWA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'RADLWA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 115 ;
}
'RADGLOA-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 117 ;
}
'FLLAT-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 121 ;
}
'FLSEN-JM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 122 ;
}
'UFLMOM-NM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 124 ;
}
'VFLMOM-NM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 125 ;
}
'ICINGWARN-N' = {
	table2Version = 253 ;
	indicatorOfParameter = 135 ;
}
'PRECTYPE-N' = {
	table2Version = 253 ;
	indicatorOfParameter = 144 ;
}
'CAPE-JKG' = {
	table2Version = 253 ;
	indicatorOfParameter = 160 ;
}
'WGU-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 162 ;
}
'WGV-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 163 ;
}
'RRI-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 181 ;
}
'SNACC-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'SNRI-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'RRS-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 185 ;
}
'CLDBASE-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 186 ;
}
'CLDTOP-M' = {
	table2Version = 253 ;
	indicatorOfParameter = 187 ;
}
'TKEN-JKG' = {
	table2Version = 253 ;
	indicatorOfParameter = 200 ;
}
'GR-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'GRI-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'RRH-KGM2' = {
	table2Version = 253 ;
	indicatorOfParameter = 204 ;
}
'FL-MPLTY-N' = {
	table2Version = 253 ;
	indicatorOfParameter = 209 ;
}
'REFLTY-DBZ' = {
	table2Version = 253 ;
	indicatorOfParameter = 210 ;
}
'FFG-MS' = {
	table2Version = 253 ;
	indicatorOfParameter = 228 ;
}
