# modelName: Contribution from Daniel Lee @ DWD

# COSMO
# general definition
'cosmo' = { originatingCentre=250; }
'cosmo' = { subCentre=250; }

# definitions for ARPA-SIMC
'cosmo-i2' = { originatingCentre=200;
                generatingProcessIdentifier=36; }
'cosmo-i2' = { originatingCentre=200;
                generatingProcessIdentifier=139; }
'cosmo-i2' = { originatingCentre=200;
                generatingProcessIdentifier=144; }
'cosmo-i2' = { originatingCentre=200;
                generatingProcessIdentifier=148; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=31; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=32; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=34; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=38; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=42; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=46; }
'cosmo-i7' = { originatingCentre=200;
                generatingProcessIdentifier=131; }
# definitions for Moscow
'cosmo_ru' = { originatingCentre=76;
                generatingProcessIdentifier=135; }
'cosmo_ru-eps' = { originatingCentre=76;
                generatingProcessIdentifier=235;}

# definitions for Athens
'cosmo-greece' = { originatingCentre=96;}
# definitions for Warsaw / Poland
'cosmo-poland' = { originatingCentre=220;}
# definitions for Romania
'cosmo-romania' = { originatingCentre=242;}

