# Local definition 16: Seasonal forecast monthly mean data

unsigned[2] systemNumber : dump;
unsigned[2] methodNumber : dump;

alias local.systemNumber=systemNumber;
alias local.methodNumber=methodNumber;
